----------------------------------------------------------------
--Create AMLCTR tables, aliases, constraints, and indexes.
----------------------------------------------------------------
--Description:
--Create AMLCTR tables, aliases, constraints, and indexes.
--This script is a template for creating the bufferpools
--required for the 'base' AML Knowledge Center schema.
--
--This script must be run as a user with SYSADM or DBADM privileges.
--
--This script assumes that two multibank segments are being
--created (BANK1CORE/BANK1KCTR AND BANK2CORE/BANK2KCTR). If more 
--are required then this script must be modified to create each of
--the individual segment schema owner's objects in the additional
--segment schema. We suggest that you copy the DDL for 
--BANK1CORE/BANK1KCTR, substitute your schema name, and run
--the additional statments for each segment added.
--------------------------------------------------------------
--------------------------------------------------------------

CREATE SET TABLE AMLCTR.FSK_ACCOUNT_EVENT_ALERT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      alert_id DECIMAL(10,0) NOT NULL,
      transaction_key DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      account_key DECIMAL(10,0) NOT NULL,
      date_key DECIMAL(8,0) NOT NULL,
      transaction_type_key DECIMAL(10,0) NOT NULL,
      time_key DECIMAL(6,0) NOT NULL,
      country_key DECIMAL(5,0) NOT NULL,
      branch_key DECIMAL(10,0) NOT NULL,
      transaction_status_key DECIMAL(5,0) NOT NULL,
      trigger_ind CHAR(1))
UNIQUE PRIMARY INDEX XPKFSK_ACCOUNT_EVENT_ALERT ( alert_id ,transaction_key ,
segment_id )
INDEX XIE1FSK_ACCOUNT_EVENT_ALERT ( account_key )
INDEX XIE2FSK_ACCOUNT_EVENT_ALERT ( transaction_key )
INDEX XIE3FSK_ACCOUNT_EVENT_ALERT ( transaction_type_key )
INDEX XIE4FSK_ACCOUNT_EVENT_ALERT ( branch_key )
INDEX XIE5FSK_ACCOUNT_EVENT_ALERT ( date_key );


COMMENT ON TABLE AMLCTR.FSK_ACCOUNT_EVENT_ALERT IS 'Replicated table from Core'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_EVENT_ALERT.alert_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_EVENT_ALERT.transaction_key IS 'Foreign Key to the transaction dimension.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_EVENT_ALERT.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_EVENT_ALERT.account_key IS 'Foreign key to the account table.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_EVENT_ALERT.date_key IS 'Note: this is normally a system-generated surrogate key, but for performance reasons we are using a numeric form of the date:

yyyymmdd'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_EVENT_ALERT.transaction_type_key IS 'Surrogate key.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_EVENT_ALERT.time_key IS 'Number of Seconds since Midnight'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_EVENT_ALERT.country_key IS 'System generated surrogate key.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_EVENT_ALERT.branch_key IS 'Surrogate identifier.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_EVENT_ALERT.transaction_status_key IS 'Foreign key to the transaction status dimension.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_EVENT_ALERT.trigger_ind IS 'Is this a triggering transaction i.e. did it contribute to the alert.  Y/N'
;


CREATE SET TABLE AMLCTR.FSK_ACCOUNT_PROFILE_ALERT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      alert_id DECIMAL(10,0) NOT NULL,
      month_key DECIMAL(6,0) NOT NULL,
      account_number VARCHAR(50) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      transactions_count DECIMAL(10,0),
      deposits_count DECIMAL(10,0),
      withdrawals_count DECIMAL(10,0),
      wires_count DECIMAL(10,0),
      cash_transactions_count DECIMAL(10,0),
      account_value_amount DECIMAL(18,5),
      total_transactions_amount DECIMAL(18,5),
      total_credits_amount DECIMAL(18,5),
      total_debits_amount DECIMAL(18,5),
      total_cash_debits_amount DECIMAL(18,5),
      total_cash_credits_amount DECIMAL(18,5),
      total_wire_credits_amount DECIMAL(18,5),
      total_wire_debits_amount DECIMAL(18,5),
      beginning_balance_amount DECIMAL(18,5),
      average_daily_balance_amount DECIMAL(18,5),
      ending_cash_balance_amount DECIMAL(18,5),
      max_account_value_amount DECIMAL(18,5),
      min_account_value_amount DECIMAL(18,5),
      avg_account_value_amount DECIMAL(18,5),
      cust_initiated_trans_count DECIMAL(10,0),
      largest_credit_amount DECIMAL(18,5),
      largest_debit_amount DECIMAL(18,5))
UNIQUE PRIMARY INDEX XPKFSK_ACCOUNT_PROFILE_ALERT ( alert_id ,
month_key ,account_number ,segment_id );


COMMENT ON TABLE AMLCTR.FSK_ACCOUNT_PROFILE_ALERT IS 'Replicated table from Core.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.alert_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.month_key IS 'System generated surrogate identifier.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.account_number IS 'Natural key of the account.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.transactions_count IS 'Total number of transactions in the account during the profile period.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.deposits_count IS 'Total number of deposits in the account during the profile period.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.withdrawals_count IS 'Total number of withdrawals in the account during the profile period.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.wires_count IS 'Total number of wires (in and out) in the account during the profile period.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.cash_transactions_count IS 'Total number of cash transactions in the account during the profile period.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.account_value_amount IS 'Total Account Market Value at end of period.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.total_transactions_amount IS 'Total money amount of all transactions (add up all debits and credits)'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.total_credits_amount IS 'Total credits ($) to the account duing the period.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.total_debits_amount IS 'Total debits ($) to the account during the period.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.total_cash_debits_amount IS 'Total Cash debits ($) to the account during the period.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.total_cash_credits_amount IS 'Total Cash credits ($) to the account during the period.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.total_wire_credits_amount IS 'Total Wire Credits ($) to the account during the period.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.total_wire_debits_amount IS 'Total Wire debits ($) to the account during the period.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.beginning_balance_amount IS 'Balance at the beginning of the period'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.average_daily_balance_amount IS 'Average Daily balance during the period'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.ending_cash_balance_amount IS 'Balance at the end of the period.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.max_account_value_amount IS 'Maximum value of account during the month.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.min_account_value_amount IS 'Minimum value of account during the month.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.avg_account_value_amount IS 'Average value of account during the month.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.cust_initiated_trans_count IS 'Number of transactions initiated by the customer (vs. by the bank) during the month.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.largest_credit_amount IS 'Largest single credit transaction for the month.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_PROFILE_ALERT.largest_debit_amount IS 'Largest single debit transaction for the month.'
;


CREATE SET TABLE AMLCTR.FSK_ACCOUNT_TRADE_ALERT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      alert_id DECIMAL(10,0) NOT NULL,
      transaction_key DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      account_key DECIMAL(10,0) NOT NULL,
      branch_key DECIMAL(10,0),
      transaction_type_key DECIMAL(10,0),
      transaction_status_key DECIMAL(5,0),
      trade_date_key DECIMAL(8,0),
      associate_key DECIMAL(10,0),
      execution_time_key DECIMAL(6,0),
      posted_date_key DECIMAL(8,0) NOT NULL,
      settlement_date_key DECIMAL(8,0) NOT NULL,
      quantity_executed DECIMAL(15,5),
      execution_price DECIMAL(10,5),
      transaction_currency_key DECIMAL(5,0),
      principal_amount_in_txn_ccy DECIMAL(15,5),
      principal_amount DECIMAL(15,5),
      principal_amount_in_acct_ccy DECIMAL(15,5) NOT NULL,
      trigger_ind CHAR(1))
UNIQUE PRIMARY INDEX XPKFSK_ACCOUNT_TRADE_ALERT ( alert_id ,transaction_key ,
segment_id )
INDEX XIE1FSK_ACCOUNT_TRADE_ALERT ( account_key )
INDEX XIE2FSK_ACCOUNT_TRADE_ALERT ( transaction_key ,transaction_type_key )
INDEX XIE3FSK_ACCOUNT_TRADE_ALERT ( associate_key );


COMMENT ON TABLE AMLCTR.FSK_ACCOUNT_TRADE_ALERT IS 'A record of brokerage trading transactions.  e.g. buying and selling equities.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_TRADE_ALERT.alert_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_TRADE_ALERT.transaction_key IS 'Foreign Key to the transaction dimension.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_TRADE_ALERT.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_TRADE_ALERT.account_key IS 'System generated surrogate key.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_TRADE_ALERT.branch_key IS 'Surrogate identifier..'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_TRADE_ALERT.transaction_type_key IS 'Surrogate key'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_TRADE_ALERT.transaction_status_key IS 'System generated surrogate key.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_TRADE_ALERT.trade_date_key IS 'Note: this is normally a system-generated surrogate key, but for performance reasons we are using a numeric form of the date:

yyyymmdd'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_TRADE_ALERT.associate_key IS 'System generated surrogate identifier'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_TRADE_ALERT.execution_time_key IS 'System generated surrogate key.  Is NOT of form hhmmss in tables though it does come in that way in the stage files.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_TRADE_ALERT.posted_date_key IS 'Date the trade was posted to the system.  e.g. the trade could occur Thursday PM but due to system outages the trades don''t get posted until Friday AM.

'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_TRADE_ALERT.settlement_date_key IS 'Date the trade was settled.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_TRADE_ALERT.quantity_executed IS 'Quantity actually purchased/sold.  Could be different to quantity ordered i.e. partial fills.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_TRADE_ALERT.execution_price IS 'Price at which the trade was executed.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_TRADE_ALERT.transaction_currency_key IS 'Surrogate key.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_TRADE_ALERT.principal_amount_in_txn_ccy IS 'aka trade amount in txn currency e.g. EUR 10,000'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_TRADE_ALERT.principal_amount IS 'aka trade amount in base currency e.g. $10,000.  Principal amount is the face value of security traded.  e.g. Buy 10,000 of bond X at price $980 - the principal amount is 10,000.  The gross amount of the trade is $9,800 plus any accrued interest.

For e'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_TRADE_ALERT.principal_amount_in_acct_ccy IS 'The amount of the transaction in the denomination currency of the account.'
;


COMMENT ON COLUMN AMLCTR.FSK_ACCOUNT_TRADE_ALERT.trigger_ind IS 'Is this a triggering transaction i.e. did it contribute to the alert.  Y/N'
;


CREATE SET TABLE AMLCTR.FSK_ALERT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      alert_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      product_type CHAR(3) NOT NULL,
      alert_status_code CHAR(3) NOT NULL,
      money_laundering_risk_score DECIMAL(3,0) NOT NULL,
      terror_financing_risk_score DECIMAL(3,0),
      alert_description VARCHAR(100) NOT NULL,
      alert_suppressed_ind CHAR(1),
      primary_entity_level_code CHAR(3) NOT NULL,
      primary_entity_number VARCHAR(50) NOT NULL,
      primary_entity_key DECIMAL(10,0),
      primary_entity_name VARCHAR(35),
      scenario_id DECIMAL(10,0),
      scenario_name VARCHAR(35),
      suppression_end_date TIMESTAMP(6),
      actual_values_text VARCHAR(255),
      user_id DECIMAL(10,0) NOT NULL,
      group_id DECIMAL(10,0) NOT NULL,
      run_date TIMESTAMP(6) NOT NULL,
      create_date TIMESTAMP(6) NOT NULL,
      create_user_id VARCHAR(35) NOT NULL,
      opened_ind CHAR(1) NOT NULL,
      employee_ind CHAR(1),
      version_number DECIMAL(10,0) NOT NULL,
      logical_delete_ind CHAR(1) NOT NULL, 
CONSTRAINT FK_ALERT_SCENARIO FOREIGN KEY ( segment_id ,scenario_id ) REFERENCES AMLCTR.FSK_SCENARIO ( segment_id ,
scenario_id ))
UNIQUE PRIMARY INDEX PK_ALERT ( alert_id ,segment_id )
INDEX XIE5FSK_ALERT ( primary_entity_key )
INDEX XIE6FSK_ALERT ( primary_entity_name )
INDEX XIE7FSK_ALERT ( user_id )
INDEX XIE8FSK_ALERT ( group_id )
INDEX XIE9FSK_ALERT ( primary_entity_number );


COMMENT ON TABLE AMLCTR.FSK_ALERT IS 'Details of a potentially suspicious entity identified as a result of scenarios and risk factors triggering.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.alert_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.product_type IS 'Product that the scenario is defined for:  e.g. AML-Anti-Money Laundering, SUR-Surveillance'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.alert_status_code IS 'Status: Active (ACT), Closed(CLS), Checked Out (OUT), Suppressed New (SUP), Suppressed Existing (SUE).

Note: "SUP" means it is a brand new alert that has been suppressed by the suppression process.  "SUE" means that there is an existing alert that caus'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.money_laundering_risk_score IS 'A measure of the importance or relevance of money laundering alerts relative to other money laundering alerts. Scale: 1-999.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.terror_financing_risk_score IS 'A measure of the importance or relevance of terrorist financing alerts relative to other terrorist financing alerts. Scale: 1-999.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.alert_description IS 'Freeform text description.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.alert_suppressed_ind IS 'Is the alert suppressed i.e. is stored but not viewed alongside non-suppressed alerts. Values are Y/N.  

This indicator is initially set in the UI, but for subsequent alerts suppressed due to the original indicator the data management process will set '
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.primary_entity_level_code IS 'ACC, PTY, HHD, ASC, BLT'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.primary_entity_number IS 'Natural key of primary entity (party, account, hhld) associated with the alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.primary_entity_key IS 'Surrogate key of primary entity (party, account, hhld) associated with the alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.primary_entity_name IS 'Name of primary entity (party, account, hhld) associated with the alert. This is redundantly stored to facilitate fast display of alert list.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.scenario_id IS 'Synthetic unique identifier of Scenarios.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.scenario_name IS 'Name of scenario.  Redundantly stored to facilitate fast display of alert list.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.suppression_end_date IS 'Date after which the alert will no longer be suppressed.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.actual_values_text IS 'The actual values that triggered the alert.  For example, a threshold may have been set at $10,000 and a transaction of $14,000 triggered this alert.  The $14,000 figure is captured here for reference.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.user_id IS 'Which user the alert is assigned to.

If not used, value = -1.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.group_id IS 'Which group the alert is assigned to.

If not used, value = -1.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.run_date IS 'Which batch asof date the alert was generated from.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.create_date IS 'When the alert was created'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.create_user_id IS 'User who inserted the record into the database.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.opened_ind IS 'Has this alert been opened or actioned by anyone since creation (Y/N).'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.employee_ind IS 'Is the entity of interest an employee of the client. Y/N'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.version_number IS 'Used to implement optimistic locking.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT.logical_delete_ind IS 'Has the record been logically deleted. Y/N'
;


CREATE SET TABLE AMLCTR.FSK_ALERT_COMMENT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      comment_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      alert_id DECIMAL(10,0) NOT NULL,
      alert_comment_text VARCHAR(2000) NOT NULL,
      item_id DECIMAL(10,0),
      create_date TIMESTAMP(6) NOT NULL,
      create_user_id VARCHAR(35) NOT NULL,
      logical_delete_ind CHAR(1) NOT NULL, 
CONSTRAINT FK_ALERT_COMMENT_ALERT FOREIGN KEY ( segment_id ,alert_id ) REFERENCES AMLCTR.FSK_ALERT ( segment_id ,
alert_id ))
UNIQUE PRIMARY INDEX PK_ALERT_COMMENT ( comment_id ,segment_id );


COMMENT ON TABLE AMLCTR.FSK_ALERT_COMMENT IS 'Details of user comments added to the alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_COMMENT.comment_id IS 'Unique system generated synthetic key used to uniquely identify an alert comment.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_COMMENT.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_COMMENT.alert_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.

'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_COMMENT.alert_comment_text IS 'Freeform text comment.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_COMMENT.item_id IS 'Used only for Trade Blotter.  It identifies which trade (=transaction_key) within a blotter this comment describes.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_COMMENT.create_date IS 'Date the comment was added to the alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_COMMENT.create_user_id IS 'Which user added the comment.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_COMMENT.logical_delete_ind IS 'Has the record been logically deleted. Y/N'
;

CREATE SET TABLE AMLCTR.FSK_ALERT_DOCUMENT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      document_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      alert_id DECIMAL(10,0) NOT NULL,
      document_name VARCHAR(255) NOT NULL,
      document_mime_type_desc VARCHAR(255) NOT NULL,
      document_location_desc VARCHAR(2000) NOT NULL,
      document_file_name VARCHAR(255) NOT NULL,
      document_desc VARCHAR(255),
      create_date TIMESTAMP(6) NOT NULL,
      create_user_id VARCHAR(35) NOT NULL,
      logical_delete_ind CHAR(1) NOT NULL, 
CONSTRAINT FK_ALERT_DOCUMENT_ALERT FOREIGN KEY ( segment_id ,
alert_id ) REFERENCES AMLCTR.FSK_ALERT ( segment_id ,alert_id ))
UNIQUE PRIMARY INDEX PK_ALERT_DOCUMENT ( document_id ,segment_id );

COMMENT ON TABLE AMLCTR.FSK_ALERT_DOCUMENT IS 'Details of user documents added to the alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_DOCUMENT.document_id IS 'Unique system generated synthetic identifier for  an alert document.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_DOCUMENT.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_DOCUMENT.alert_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_DOCUMENT.document_name IS 'English name for the document.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_DOCUMENT.document_mime_type_desc IS 'mime type e.g. Word, Excel.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_DOCUMENT.document_location_desc IS 'Document path.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_DOCUMENT.document_file_name IS 'Document file name.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_DOCUMENT.document_desc IS 'Free form user-added description.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_DOCUMENT.create_date IS 'Date the document was added to the alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_DOCUMENT.create_user_id IS 'Which user added the document.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_DOCUMENT.logical_delete_ind IS 'Has the record been logically deleted. Y/N'
;

CREATE SET TABLE AMLCTR.FSK_ALERT_EMAIL ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      email_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      alert_id DECIMAL(10,0) NOT NULL,
      email_to_text VARCHAR(2000) NOT NULL,
      email_cc_text VARCHAR(2000),
      email_subject_desc VARCHAR(255),
      email_message_text VARCHAR(4000),
      create_date TIMESTAMP(6) NOT NULL,
      create_user_id VARCHAR(35) NOT NULL, 
CONSTRAINT FK_ALERT_EMAIL_ALERT FOREIGN KEY ( segment_id ,alert_id ) REFERENCES AMLCTR.FSK_ALERT ( segment_id ,
alert_id ))
UNIQUE PRIMARY INDEX PK_ALERT_EMAIL ( email_id ,segment_id );


COMMENT ON TABLE AMLCTR.FSK_ALERT_EMAIL IS 'Details of any e-mails sent regarding the alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_EMAIL.email_id IS 'Unique system generated synthetic key used to uniquely identify an alert email.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_EMAIL.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_EMAIL.alert_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_EMAIL.email_to_text IS 'Who the email was sent to.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_EMAIL.email_cc_text IS 'Who was cc''d on the e-mail.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_EMAIL.email_subject_desc IS 'e-mail subject'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_EMAIL.email_message_text IS 'e-mail body'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_EMAIL.create_date IS 'Date the e-mail was added to the alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_EMAIL.create_user_id IS 'Which user added the e-mail to the alert.'
;

CREATE SET TABLE AMLCTR.FSK_ALERT_ENTITY ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      alert_id DECIMAL(10,0) NOT NULL,
      entity_key DECIMAL(10,0) NOT NULL,
      entity_level_code CHAR(3) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      entity_number VARCHAR(50) NOT NULL,
      entity_name VARCHAR(35), 
CONSTRAINT FK_ALERT_ENTITY_ALERT FOREIGN KEY ( alert_id ,segment_id ) REFERENCES AMLCTR.FSK_ALERT ( alert_id ,
segment_id ))
UNIQUE PRIMARY INDEX PK_ALERT_ENTITY ( alert_id ,entity_key ,
entity_level_code ,segment_id )
INDEX XIE1FSK_ALERT_ENTITY ( entity_number )
INDEX XIE2FSK_ALERT_ENTITY ( entity_key );

COMMENT ON TABLE AMLCTR.FSK_ALERT_ENTITY IS 'Details of additional entities involved in the alert (for future use).'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_ENTITY.alert_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_ENTITY.entity_key IS 'Surrogate identifier of the entity.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_ENTITY.entity_level_code IS 'What type of entity: ACC,PTY,HHD,ASC'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_ENTITY.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_ENTITY.entity_number IS 'Source system identifier of the entity (Acct, Party, Hhld, Assoc).'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_ENTITY.entity_name IS 'Name of the entity stored redundantly to improve list performance.'
;

CREATE SET TABLE AMLCTR.FSK_ALERT_EVENT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      event_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      alert_id DECIMAL(10,0) NOT NULL,
      event_type_code CHAR(3) NOT NULL,
      event_description VARCHAR(255),
      create_date TIMESTAMP(6) NOT NULL,
      create_user_id VARCHAR(35) NOT NULL, 
CONSTRAINT FK_ALERT_EVENT_ALERT FOREIGN KEY ( segment_id ,alert_id ) REFERENCES AMLCTR.FSK_ALERT ( segment_id ,
alert_id ))
UNIQUE PRIMARY INDEX PK_ALERT_EVENT ( event_id ,segment_id );


COMMENT ON TABLE AMLCTR.FSK_ALERT_EVENT IS 'Details of all actions taken on the alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_EVENT.event_id IS 'A system generated synthetic key used to uniquely identify an instance of an alert event.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_EVENT.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_EVENT.alert_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_EVENT.event_type_code IS 'Describes whether the event was for example: "Alert Checked In", "Alert Checked Out" etc.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_EVENT.event_description IS 'Free-form description of the event.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_EVENT.create_date IS 'Date the record was created.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_EVENT.create_user_id IS 'Who created the record.'
;

CREATE SET TABLE AMLCTR.FSK_ALERT_REMINDER ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      alert_id DECIMAL(10,0) NOT NULL,
      user_id DECIMAL(10,0) NOT NULL,
      reminder_date TIMESTAMP(6) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      reminder_sent_ind CHAR(1), 
CONSTRAINT R_67 FOREIGN KEY ( alert_id ,segment_id ) REFERENCES AMLCTR.FSK_ALERT ( alert_id ,
segment_id ),
CONSTRAINT R_68 FOREIGN KEY ( user_id ,segment_id ) REFERENCES AMLCTR.FSK_USER ( user_id ,
segment_id ))
UNIQUE PRIMARY INDEX XPKFSK_ALERT_REMINDER ( alert_id ,user_id ,
reminder_date ,segment_id );

COMMENT ON TABLE AMLCTR.FSK_ALERT_REMINDER IS 'Via the UI, users can request to be reminded to review an alert after a certain number of days.  This table stores those requests.  A batch job reviews this table daily and generates reminder e-mails as necessary.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_REMINDER.alert_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_REMINDER.user_id IS 'System generated identifier'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_REMINDER.reminder_date IS 'Date on which the e-mail should be sent (i.e. should first appear in the recipient''s inbox).
'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_REMINDER.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_REMINDER.reminder_sent_ind IS 'Has the reminder been sent (Y/N).'
;



CREATE SET TABLE AMLCTR.FSK_ALERT_RISK_FACTOR ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      alert_id DECIMAL(10,0) NOT NULL,
      scenario_id DECIMAL(10,0) NOT NULL,
      entity_number VARCHAR(50) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      entity_level_code CHAR(3) NOT NULL,
      actual_values_text VARCHAR(255), 
CONSTRAINT R_51 FOREIGN KEY ( alert_id ,segment_id ) REFERENCES AMLCTR.FSK_ALERT ( alert_id ,
segment_id ),
CONSTRAINT R_52 FOREIGN KEY ( scenario_id ,segment_id ) REFERENCES AMLCTR.FSK_SCENARIO ( scenario_id ,
segment_id ))
UNIQUE PRIMARY INDEX XPKFSK_ALERT_RISK_FACTOR ( alert_id ,scenario_id ,
entity_number ,segment_id )
INDEX XIE2FSK_ALERT_RISK_FACTOR ( entity_number );


COMMENT ON TABLE AMLCTR.FSK_ALERT_RISK_FACTOR IS 'Details of risk factors influencing the score for this alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_RISK_FACTOR.alert_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_RISK_FACTOR.scenario_id IS 'Synthetic unique identifier of Scenarios.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_RISK_FACTOR.entity_number IS 'Source system identifier of the entity (Acct, Party, Hhld, Assoc).'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_RISK_FACTOR.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_RISK_FACTOR.entity_level_code IS 'What type of entity: ACC,PTY,HHD,ASC'
;


COMMENT ON COLUMN AMLCTR.FSK_ALERT_RISK_FACTOR.actual_values_text IS 'The actual values that triggered the alert.  For example, a threshold may have been set at $10,000 and a transaction of $14,000 triggered this alert.  The $14,000 figure is captured here for reference.'
;

CREATE SET TABLE AMLCTR.FSK_ASSESSMENT_ROUTING_RULE ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      routing_rule_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      list_id DECIMAL(10,0),
      risk_assessment_column_name VARCHAR(30) NOT NULL,
      route_priority_number DECIMAL(3,0),
      route_type_code DECIMAL(1,0),
      initial_route_id DECIMAL(10,0), 
CONSTRAINT R_100 FOREIGN KEY ( segment_id ,list_id ) REFERENCES AMLCTR.FSK_LIST ( segment_id ,
list_id ))
UNIQUE PRIMARY INDEX XPKFSK_ASSESSMENT_ROUTING_RULE ( routing_rule_id ,
segment_id );


COMMENT ON TABLE AMLCTR.FSK_ASSESSMENT_ROUTING_RULE IS 'A set of constraints forming a rule to govern the initial routing of an alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_ASSESSMENT_ROUTING_RULE.routing_rule_id IS 'Unique identifier within routing_group_id to identify a routing rule.'
;


COMMENT ON COLUMN AMLCTR.FSK_ASSESSMENT_ROUTING_RULE.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_ASSESSMENT_ROUTING_RULE.list_id IS 'System generated synthetic/surrogate key that uniquely identifies a risk list.'
;


COMMENT ON COLUMN AMLCTR.FSK_ASSESSMENT_ROUTING_RULE.risk_assessment_column_name IS 'Column in the fsk_risk_assessment table which contains the value that this rule is based on.'
;


COMMENT ON COLUMN AMLCTR.FSK_ASSESSMENT_ROUTING_RULE.route_priority_number IS 'A prioritization of rule execution.  Higher priorities take precedence over lower.'
;


COMMENT ON COLUMN AMLCTR.FSK_ASSESSMENT_ROUTING_RULE.route_type_code IS 'Is the assessment being routed to a group ("0") or to a user ("1").'
;


COMMENT ON COLUMN AMLCTR.FSK_ASSESSMENT_ROUTING_RULE.initial_route_id IS 'The ID of the user or group for initial routing.'
;


CREATE SET TABLE AMLCTR.FSK_ASSESSMENT_SEQUENCE ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      next_sequence_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) DEFAULT USER )
PRIMARY INDEX ( next_sequence_id );


COMMENT ON TABLE AMLCTR.FSK_ASSESSMENT_SEQUENCE IS 'Used to generate unique identifiers for risk assessment tables.'
;


COMMENT ON COLUMN AMLCTR.FSK_ASSESSMENT_SEQUENCE.next_sequence_id IS 'The next identifier available to be used.  The user should read this value and immediately increment, update and commit to allow the next user access.'
;


COMMENT ON COLUMN AMLCTR.FSK_ASSESSMENT_SEQUENCE.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


CREATE SET TABLE AMLCTR.FSK_CASH_FLOW_ALERT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      alert_id DECIMAL(10,0) NOT NULL,
      transaction_key DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      account_key DECIMAL(10,0) NOT NULL,
      date_key DECIMAL(8,0) NOT NULL,
      time_key DECIMAL(6,0) NOT NULL,
      transaction_type_key DECIMAL(10,0) NOT NULL,
      country_key DECIMAL(5,0) NOT NULL,
      transaction_status_key DECIMAL(5,0) NOT NULL,
      remitter_ext_party_key DECIMAL(10,0),
      beneficiary_ext_party_key DECIMAL(10,0) NOT NULL,
      transaction_currency_key DECIMAL(5,0) NOT NULL,
      branch_key DECIMAL(10,0) NOT NULL,
      posted_date_key DECIMAL(8,0),
      associate_key DECIMAL(10,0),
      executing_party_key DECIMAL(10,0),
      currency_amount DECIMAL(15,5),
      currency_amount_in_txn_ccy DECIMAL(15,5),
      currency_amount_in_account_ccy DECIMAL(15,5),
      secondary_account_key DECIMAL(10,0) NOT NULL,
      related_ind CHAR(1) NOT NULL DEFAULT 'N',
      trigger_ind CHAR(1),
      third_party_ind CHAR(1))
UNIQUE PRIMARY INDEX XPKFSK_CASH_FLOW_ALERT ( alert_id ,transaction_key ,
segment_id )
INDEX XIE1FSK_CASH_FLOW_ALERT ( account_key )
INDEX XIE2FSK_CASH_FLOW_ALERT ( transaction_key ,transaction_type_key )
INDEX XIE3FSK_CASH_FLOW_ALERT ( associate_key )
INDEX XIE4FSK_CASH_FLOW_ALERT ( executing_party_key )
INDEX XIE5FSK_CASH_FLOW_ALERT ( date_key );

COMMENT ON TABLE AMLCTR.FSK_CASH_FLOW_ALERT IS 'Replicated table from Core.'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_ALERT.alert_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_ALERT.transaction_key IS 'Foreign key to the trransaction dimension.'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_ALERT.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_ALERT.account_key IS 'Foreign key to the account table.'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_ALERT.date_key IS 'Note: this is normally a system-generated surrogate key, but for performance reasons we are using a numeric form of the date:

yyyymmdd'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_ALERT.time_key IS 'Number of Seconds since Midnight'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_ALERT.transaction_type_key IS 'FK to TRANSACTION_TYPE_DIM table.'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_ALERT.country_key IS 'Country where transaction occurred.  This is a short-cut primarily for wires to avoid having to query the wire dimensions.'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_ALERT.transaction_status_key IS 'Foreign key to the transaction status dimension'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_ALERT.transaction_currency_key IS 'Original transaction currency.'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_ALERT.branch_key IS 'Surrogate identifier.'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_ALERT.posted_date_key IS 'Date the transaction was posted to the source system.'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_ALERT.associate_key IS 'System generated surrogate identifier'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_ALERT.executing_party_key IS 'Party that initiated the transaction.'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_ALERT.currency_amount IS 'Amount of the transaction expressed in the base/reporting currency.'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_ALERT.currency_amount_in_txn_ccy IS 'Amount of the transaction expressed in the original currency of the transaction.'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_ALERT.currency_amount_in_account_ccy IS 'The amount of the transaction in the denomination currency of the account.'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_ALERT.secondary_account_key IS 'Used to identify a secondary internal account associated with an internal transfer.  e.g. for a  transfer from savings to checking, the savings account is account_key, the checking account is secondary_account_key.  If not used set to -1.'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_ALERT.related_ind IS 'Is the transaction between two related accounts e.g. a transfer between one person''s checking and savings accounts or a wire between spouses.  This flag must be set by the ETL - it cannot be derived.'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_ALERT.trigger_ind IS 'Is this a triggering transaction i.e. did it contribute to the alert.  Y/N'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_ALERT.third_party_ind IS 'Is there a thrid party (i.e. non-customer) associated with this transaction Y/N.'
;

CREATE SET TABLE AMLCTR.FSK_CASH_FLOW_BANK_ALERT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      alert_id DECIMAL(10,0) NOT NULL,
      bank_key DECIMAL(10,0) NOT NULL,
      transaction_key DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      role_desc VARCHAR(20),
      sequence_number DECIMAL(2,0))
UNIQUE PRIMARY INDEX XPKFSK_CASH_FLOW_BANK_AL ( alert_id ,bank_key ,
transaction_key ,segment_id );

COMMENT ON TABLE AMLCTR.FSK_CASH_FLOW_BANK_ALERT IS 'A record of which banks play a role on a given cash flow transaction.  Roles include REMITTER and BENEFICIARY.'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_BANK_ALERT.alert_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_BANK_ALERT.bank_key IS 'System generated surrogate identifier'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_BANK_ALERT.transaction_key IS 'Surrogate key'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_BANK_ALERT.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_BANK_ALERT.role_desc IS 'Role that the bank plays in the transaction.

Starter Values are:
BENEFICIARY
REMITTER
CORRESPONDENT
INTERMEDIARY

Note: Likely not possible to be able to differentiate between correspondent and intermediary - probably best to just use intermediar'
;


COMMENT ON COLUMN AMLCTR.FSK_CASH_FLOW_BANK_ALERT.sequence_number IS 'Order in which the bank handled the monies.'
;


CREATE SET TABLE AMLCTR.FSK_ENTITY_COMMENT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      comment_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      entity_level_code CHAR(3) NOT NULL,
      entity_number VARCHAR(50),
      comment_text VARCHAR(2000) NOT NULL,
      create_date TIMESTAMP(6) NOT NULL,
      create_user_id VARCHAR(35) NOT NULL,
      lstupdate_user_id VARCHAR(35),
      lstupdate_date TIMESTAMP(6),
      logical_delete_ind CHAR(1) NOT NULL)
UNIQUE PRIMARY INDEX XPKFSK_ENTITY_COMMENT ( comment_id ,segment_id );


COMMENT ON TABLE AMLCTR.FSK_ENTITY_COMMENT IS 'Details of user-added comments for an entity (Party, Account, Household).'
;


COMMENT ON COLUMN AMLCTR.FSK_ENTITY_COMMENT.comment_id IS 'Unique system generated synthetic key used to uniquely identify a comment.'
;


COMMENT ON COLUMN AMLCTR.FSK_ENTITY_COMMENT.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_ENTITY_COMMENT.entity_level_code IS 'ACC, PTY, HHD'
;


COMMENT ON COLUMN AMLCTR.FSK_ENTITY_COMMENT.entity_number IS 'Natural key of primary entity (party, account, hhld)'
;


COMMENT ON COLUMN AMLCTR.FSK_ENTITY_COMMENT.comment_text IS 'Freeform text comment.'
;


COMMENT ON COLUMN AMLCTR.FSK_ENTITY_COMMENT.create_date IS 'Date the comment was added to the alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_ENTITY_COMMENT.create_user_id IS 'Which user added the comment.'
;


COMMENT ON COLUMN AMLCTR.FSK_ENTITY_COMMENT.lstupdate_user_id IS 'Who last updated the header.'
;


COMMENT ON COLUMN AMLCTR.FSK_ENTITY_COMMENT.lstupdate_date IS 'When was the header last updated.'
;


COMMENT ON COLUMN AMLCTR.FSK_ENTITY_COMMENT.logical_delete_ind IS 'Has the record been logically deleted. Y/N'
;

CREATE SET TABLE AMLCTR.FSK_ENTITY_DOCUMENT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      document_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      entity_level_code CHAR(3) NOT NULL,
      entity_number VARCHAR(50),
      document_name VARCHAR(255) NOT NULL,
      document_mime_type_desc VARCHAR(255) NOT NULL,
      document_location_desc VARCHAR(2000) NOT NULL,
      document_file_name VARCHAR(255) NOT NULL,
      document_desc VARCHAR(255),
      create_date TIMESTAMP(6) NOT NULL,
      create_user_id VARCHAR(35) NOT NULL,
      lstupdate_user_id VARCHAR(35),
      lstupdate_date TIMESTAMP(6),
      logical_delete_ind CHAR(1) NOT NULL)
UNIQUE PRIMARY INDEX XPKFSK_ENTITY_DOCUMENT ( document_id ,segment_id )
INDEX XIE1FSK_ENTITY_DOCUMENT ( segment_id ,entity_level_code ,
entity_number );


COMMENT ON TABLE AMLCTR.FSK_ENTITY_DOCUMENT IS 'Details of user documents added to the entity.'
;


COMMENT ON COLUMN AMLCTR.FSK_ENTITY_DOCUMENT.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;

CREATE SET TABLE AMLCTR.FSK_GROUP ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      group_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      group_name VARCHAR(35) NOT NULL,
      group_desc VARCHAR(35) NOT NULL,
      version_number DECIMAL(10,0) NOT NULL,
      logical_delete_ind CHAR(1) NOT NULL)
UNIQUE PRIMARY INDEX PK_GROUP ( group_id ,segment_id );


COMMENT ON TABLE AMLCTR.FSK_GROUP IS 'An alert grouping mechanism used to divide workload in to manageable pieces.'
;


COMMENT ON COLUMN AMLCTR.FSK_GROUP.group_id IS 'A synthetic identifier used to uniquely identify user groups.'
;


COMMENT ON COLUMN AMLCTR.FSK_GROUP.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_GROUP.group_name IS 'A label for the group.'
;


COMMENT ON COLUMN AMLCTR.FSK_GROUP.group_desc IS 'A freeform text description of the group.
'
;


COMMENT ON COLUMN AMLCTR.FSK_GROUP.version_number IS 'Used to implement optimistic locking.'
;


COMMENT ON COLUMN AMLCTR.FSK_GROUP.logical_delete_ind IS 'Has the row been logically deleted Y/N.'
;

CREATE SET TABLE AMLCTR.FSK_GROUP_USER ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      group_id DECIMAL(10,0) NOT NULL,
      user_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER , 
CONSTRAINT FK_GROUP_USER_GROUP FOREIGN KEY ( group_id ,segment_id ) REFERENCES AMLCTR.FSK_GROUP ( group_id ,
segment_id ),
CONSTRAINT FK_GROUP_USER_USER FOREIGN KEY ( user_id ,segment_id ) REFERENCES AMLCTR.FSK_USER ( user_id ,
segment_id ))
UNIQUE PRIMARY INDEX PK_GROUP_USER ( group_id ,user_id ,segment_id );


COMMENT ON TABLE AMLCTR.FSK_GROUP_USER IS 'Identifies which users are assigned to which groups.'
;


COMMENT ON COLUMN AMLCTR.FSK_GROUP_USER.group_id IS 'A synthetic identifier used to uniquely identify user groups.'
;


COMMENT ON COLUMN AMLCTR.FSK_GROUP_USER.user_id IS 'System generated identifier'
;


COMMENT ON COLUMN AMLCTR.FSK_GROUP_USER.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


CREATE SET TABLE AMLCTR.FSK_HEADER ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      header_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      header_name VARCHAR(32) NOT NULL,
      header_description VARCHAR(255) NOT NULL,
      entity_level_code CHAR(3) NOT NULL,
      denorm_table_name VARCHAR(255),
      alert_table_name VARCHAR(50) NOT NULL,
      header_autogen_ind CHAR(1) NOT NULL,
      header_location_desc VARCHAR(255),
      source_type_desc VARCHAR(15) NOT NULL,
      create_user_id VARCHAR(35) NOT NULL,
      create_date TIMESTAMP(6) NOT NULL,
      lstupdate_user_id VARCHAR(35),
      lstupdate_date TIMESTAMP(6),
      header_host_desc VARCHAR(50) NOT NULL,
      logical_delete_ind CHAR(1) NOT NULL)
UNIQUE PRIMARY INDEX PK_HEADER ( header_id ,segment_id );


COMMENT ON TABLE AMLCTR.FSK_HEADER IS 'Describes the properties of the header used by the scenarios.'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER.header_id IS 'Name and identifier of the header.'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER.header_name IS 'Short name for the header.'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER.header_description IS 'Header description'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER.entity_level_code IS 'Which entity level the header targets i.e. ACC, PTY, HHD, ASC.'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER.denorm_table_name IS 'Name of the denormalized table used as input to the Datastep code.'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER.alert_table_name IS 'Location of intermediate alerts.'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER.header_autogen_ind IS 'Is the header autogen''d Y/N'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER.header_location_desc IS 'Where is the header physically stored.'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER.source_type_desc IS 'e.g. SAS Datastep'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER.create_user_id IS 'Who created the header.'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER.create_date IS 'When the header was created.'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER.lstupdate_user_id IS 'Who last updated the header.'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER.lstupdate_date IS 'When was the header last updated.'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER.header_host_desc IS 'Whether running LOCALHOST or REMOTE.'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER.logical_delete_ind IS 'Has this row been logically deleted Y/N'
;

CREATE SET TABLE AMLCTR.FSK_HEADER_ELEMENT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      header_id DECIMAL(10,0) NOT NULL,
      element_name VARCHAR(35) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      element_type_code CHAR(6) NOT NULL,
      element_length_count DECIMAL(8,0),
      element_format_code CHAR(8) NOT NULL,
      element_label_desc VARCHAR(35) NOT NULL,
      element_usage_desc VARCHAR(35), 
CONSTRAINT FK_HEADER_ELEMENT_HEADER FOREIGN KEY ( header_id ,
segment_id ) REFERENCES AMLCTR.FSK_HEADER ( header_id ,segment_id ))
UNIQUE PRIMARY INDEX PK_HEADER_ELEMENT ( header_id ,element_name ,
segment_id );


COMMENT ON TABLE AMLCTR.FSK_HEADER_ELEMENT IS 'Describes the data elements used in this header.'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER_ELEMENT.header_id IS 'Name and identifier of the header.'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER_ELEMENT.element_name IS 'Element name.'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER_ELEMENT.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER_ELEMENT.element_type_code IS 'Datatype: C-Character; N-Numeric'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER_ELEMENT.element_length_count IS 'Datatype length'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER_ELEMENT.element_format_code IS 'Formatting code e.g. $50 or 27.10'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER_ELEMENT.element_label_desc IS 'Column name in Core data model.'
;


COMMENT ON COLUMN AMLCTR.FSK_HEADER_ELEMENT.element_usage_desc IS 'How it''s used in the code e.g. "Array Element" or "By Variable".'
;

CREATE SET TABLE AMLCTR.FSK_JOB_CALENDAR ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      job_calendar_id DECIMAL(5,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      calendar_date TIMESTAMP(6),
      rundate_ind CHAR(1),
      daily_rundate_ind CHAR(1) NOT NULL,
      weekly_rundate_ind CHAR(1) NOT NULL,
      monthly_rundate_ind CHAR(1) NOT NULL,
      status_ind CHAR(1) NOT NULL,
      business_day_count DECIMAL(15,0))
UNIQUE PRIMARY INDEX PK_JOB_CALENDAR ( job_calendar_id ,segment_id );

COMMENT ON TABLE AMLCTR.FSK_JOB_CALENDAR IS 'Table used to determine which days are valid run days for scenario processing.'
;


COMMENT ON COLUMN AMLCTR.FSK_JOB_CALENDAR.job_calendar_id IS 'System generated surrogate key.'
;


COMMENT ON COLUMN AMLCTR.FSK_JOB_CALENDAR.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_JOB_CALENDAR.calendar_date IS 'Calendar Date.'
;


COMMENT ON COLUMN AMLCTR.FSK_JOB_CALENDAR.rundate_ind IS 'Is today a rundate regardless of type.'
;


COMMENT ON COLUMN AMLCTR.FSK_JOB_CALENDAR.daily_rundate_ind IS 'Do daily jobs run on this day. Y/N'
;


COMMENT ON COLUMN AMLCTR.FSK_JOB_CALENDAR.weekly_rundate_ind IS 'Do weekly jobs run on this day. Y/N'
;


COMMENT ON COLUMN AMLCTR.FSK_JOB_CALENDAR.monthly_rundate_ind IS 'Do monthly jobs run on this day. Y/N'
;


COMMENT ON COLUMN AMLCTR.FSK_JOB_CALENDAR.status_ind IS 'Have the jobs completed for this day.'
;


COMMENT ON COLUMN AMLCTR.FSK_JOB_CALENDAR.business_day_count IS 'A sequential number used to track business days versus holidays or weekends.'
;


CREATE SET TABLE AMLCTR.FSK_LIST ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      list_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      list_category_id DECIMAL(10,0),
      list_name VARCHAR(35),
      list_desc VARCHAR(255),
      validation_type_code VARCHAR(4) NOT NULL,
      create_date TIMESTAMP(6),
      create_user_id VARCHAR(35),
      delete_date TIMESTAMP(6),
      delete_user_id VARCHAR(35),
      logical_delete_ind CHAR(1), 
CONSTRAINT R_72 FOREIGN KEY ( segment_id ,list_category_id ) REFERENCES AMLCTR.FSK_LIST_CATEGORY ( segment_id ,
list_category_id ))
UNIQUE PRIMARY INDEX XPKFSK_LIST ( list_id ,segment_id );


COMMENT ON TABLE AMLCTR.FSK_LIST IS 'Describes a list. Each row maps to a column in fsc_classifier_fact.'
;


COMMENT ON COLUMN AMLCTR.FSK_LIST.list_id IS 'System generated synthetic/surrogate key that uniquely identifies a risk list.'
;


COMMENT ON COLUMN AMLCTR.FSK_LIST.list_category_id IS 'System generated synthetic/surrogate key that uniquely identifies a risk list category.'
;


COMMENT ON COLUMN AMLCTR.FSK_LIST.list_name IS 'good guy, bad guy, PEP,PSP) -'
;


COMMENT ON COLUMN AMLCTR.FSK_LIST.validation_type_code IS 'Used for list element validation only. 

ACC | PTY |  NONE- use fsk_lov to match these to a specific table fsc_account_dim | fsc_party_dim |  NONE

Other values may be added for new list types, but cooresponding entries must also be added to fsk_lov.'
;


COMMENT ON COLUMN AMLCTR.FSK_LIST.logical_delete_ind IS 'Has this row been logically deleted Y/N'
;


CREATE SET TABLE AMLCTR.FSK_LIST_CATEGORY ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      list_category_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      list_category_name VARCHAR(35) NOT NULL,
      list_category_desc VARCHAR(255),
      create_date TIMESTAMP(6),
      create_user_id VARCHAR(35),
      delete_date TIMESTAMP(6),
      delete_user_id VARCHAR(35),
      logical_delete_ind CHAR(1))
UNIQUE PRIMARY INDEX XPKFSK_LIST_CATEGORY ( list_category_id ,
segment_id );


COMMENT ON TABLE AMLCTR.FSK_LIST_CATEGORY IS 'Allows grouping of risk lists into categories and holds information about the categories.'
;


COMMENT ON COLUMN AMLCTR.FSK_LIST_CATEGORY.list_category_id IS 'System generated synthetic/surrogate key that uniquely identifies a risk list category.'
;


COMMENT ON COLUMN AMLCTR.FSK_LIST_CATEGORY.list_category_name IS 'Name for the collection of risk lists. 
(e.g. geographical locations, products and services, customers and entities, account or customer descriptions)'
;


COMMENT ON COLUMN AMLCTR.FSK_LIST_CATEGORY.list_category_desc IS 'Long description of category.
'
;


COMMENT ON COLUMN AMLCTR.FSK_LIST_CATEGORY.logical_delete_ind IS 'Has this row been logically deleted Y/N'
;

CREATE SET TABLE AMLCTR.FSK_LIST_ELEMENT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      list_element_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      list_id DECIMAL(10,0),
      list_element_desc VARCHAR(35),
      list_element_value VARCHAR(75) NOT NULL,
      create_date TIMESTAMP(6),
      create_user_id VARCHAR(35),
      delete_user_id VARCHAR(35),
      logical_delete_ind CHAR(1),
      delete_date TIMESTAMP(6), 
CONSTRAINT R_73 FOREIGN KEY ( segment_id ,list_id ) REFERENCES AMLCTR.FSK_LIST ( segment_id ,
list_id ))
UNIQUE PRIMARY INDEX XPKFSK_LIST_ELEMENT ( list_element_id ,segment_id )
INDEX XIE1FSK_LIST_ELEMENT ( list_element_value );


COMMENT ON COLUMN AMLCTR.FSK_LIST_ELEMENT.list_element_id IS 'System generated synthetic/surrogate key that uniquely identifies an risk list element'
;


COMMENT ON COLUMN AMLCTR.FSK_LIST_ELEMENT.list_id IS 'System generated synthetic/surrogate key that uniquely identifies a risk list.'
;


COMMENT ON COLUMN AMLCTR.FSK_LIST_ELEMENT.logical_delete_ind IS 'Has this row been logically deleted Y/N'
;


CREATE SET TABLE AMLCTR.FSK_LOV ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      lov_type_name CHAR(18) NOT NULL,
      lov_type_code CHAR(3) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      lov_type_desc VARCHAR(35) NOT NULL,
      lov_sort_position_number INTEGER,
      lov_language_desc VARCHAR(20))
UNIQUE PRIMARY INDEX PK_LOV ( lov_type_name ,lov_type_code ,segment_id );

COMMENT ON TABLE AMLCTR.FSK_LOV IS 'Generic lookup table used throughout the AML application.'
;


COMMENT ON COLUMN AMLCTR.FSK_LOV.lov_type_name IS 'Which list of values. e.g. "Alert Type", "Rule Type".'
;


COMMENT ON COLUMN AMLCTR.FSK_LOV.lov_type_code IS 'The code value e.g. "ACT"'
;


COMMENT ON COLUMN AMLCTR.FSK_LOV.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_LOV.lov_type_desc IS 'A description of the code. e.g. "Active"'
;


COMMENT ON COLUMN AMLCTR.FSK_LOV.lov_sort_position_number IS 'Which position to display this itme in a drop-down list.  i.e. 1,2,3,....'
;


COMMENT ON COLUMN AMLCTR.FSK_LOV.lov_language_desc IS 'Specifies which language to display the code in.  Note: this is not used in AML 2.1.  Will be removed in future release.'
;


CREATE SET TABLE AMLCTR.FSK_NETWORK_EXCLUSION ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      network_exclusion_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      remitter_account_number VARCHAR(50) NOT NULL,
      beneficiary_account_number VARCHAR(50) NOT NULL,
      instruction_code CHAR(1),
      exclusion_desc VARCHAR(255),
      create_date TIMESTAMP(6) NOT NULL,
      create_user_id VARCHAR(35) NOT NULL,
      lstupdate_user_id VARCHAR(35),
      lstupdate_date TIMESTAMP(6),
      logical_delete_ind CHAR(1) NOT NULL)
UNIQUE PRIMARY INDEX XPKFSK_NETWORK_EXCLUSION ( network_exclusion_id ,
segment_id )
INDEX XIE1FSK_NETWORK_EXCLUSION ( remitter_account_number )
INDEX XIEFSK_NETWORK_EXCLUSION ( beneficiary_account_number );


COMMENT ON TABLE AMLCTR.FSK_NETWORK_EXCLUSION IS 'Denotes account-to-account relationships that should be excluded from Funds Tracker analysis.'
;


COMMENT ON COLUMN AMLCTR.FSK_NETWORK_EXCLUSION.network_exclusion_id IS 'Unique identifier.'
;


COMMENT ON COLUMN AMLCTR.FSK_NETWORK_EXCLUSION.remitter_account_number IS 'Account from which the funds are flowing.'
;


COMMENT ON COLUMN AMLCTR.FSK_NETWORK_EXCLUSION.beneficiary_account_number IS 'Account into which the funds are flowing.'
;


COMMENT ON COLUMN AMLCTR.FSK_NETWORK_EXCLUSION.instruction_code IS 'E-Exclude
R-Mark Related
U-Mark Unrelated'
;


COMMENT ON COLUMN AMLCTR.FSK_NETWORK_EXCLUSION.exclusion_desc IS 'Free from description of exclusion reason.'
;


COMMENT ON COLUMN AMLCTR.FSK_NETWORK_EXCLUSION.create_date IS 'Date the comment was added to the alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_NETWORK_EXCLUSION.create_user_id IS 'Which user added the comment.'
;


COMMENT ON COLUMN AMLCTR.FSK_NETWORK_EXCLUSION.lstupdate_user_id IS 'Who last updated the header.'
;


COMMENT ON COLUMN AMLCTR.FSK_NETWORK_EXCLUSION.lstupdate_date IS 'When was the header last updated.'
;


COMMENT ON COLUMN AMLCTR.FSK_NETWORK_EXCLUSION.logical_delete_ind IS 'Has this record been logically deleted Y/N.'
;


CREATE SET TABLE AMLCTR.FSK_PARTY_PROFILE_ALERT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      alert_id DECIMAL(10,0) NOT NULL,
      month_key DECIMAL(6,0) NOT NULL,
      party_number VARCHAR(50) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      aggregate_assets_amount DECIMAL(18,5),
      total_wire_credits_amount DECIMAL(18,5),
      total_wire_debits_amount DECIMAL(18,5),
      transactions_count DECIMAL(10,0),
      deposits_count DECIMAL(10,0),
      withdrawals_count DECIMAL(10,0),
      wires_count DECIMAL(10,0),
      cash_transactions_count DECIMAL(10,0),
      account_value_amount DECIMAL(10,0),
      total_transactions_amount DECIMAL(18,5),
      total_credits_amount DECIMAL(10,0),
      total_debits_amount DECIMAL(18,5),
      total_cash_debits_amount DECIMAL(18,5),
      total_cash_credits_amount DECIMAL(18,5),
      largest_credit_amount DECIMAL(18,5),
      largest_debit_amount DECIMAL(18,5),
      funds_payment_svcs_count DECIMAL(10,0),
      funds_transfer_count DECIMAL(10,0),
      monetary_instrument_count DECIMAL(10,0))
UNIQUE PRIMARY INDEX XPKFSK_PARTY_PROFILE_ALERT ( alert_id ,month_key ,
party_number ,segment_id );


COMMENT ON TABLE AMLCTR.FSK_PARTY_PROFILE_ALERT IS 'Replicated table from Core.'
;


COMMENT ON COLUMN AMLCTR.FSK_PARTY_PROFILE_ALERT.alert_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_PARTY_PROFILE_ALERT.month_key IS 'System generated surrogate identifier.'
;


COMMENT ON COLUMN AMLCTR.FSK_PARTY_PROFILE_ALERT.party_number IS 'Natural key of the party table.'
;


COMMENT ON COLUMN AMLCTR.FSK_PARTY_PROFILE_ALERT.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_PARTY_PROFILE_ALERT.aggregate_assets_amount IS 'Total assets across all accounts.'
;


COMMENT ON COLUMN AMLCTR.FSK_PARTY_PROFILE_ALERT.total_wire_credits_amount IS 'Total Wire Credits ($) to all accounts for the party during the period.'
;


COMMENT ON COLUMN AMLCTR.FSK_PARTY_PROFILE_ALERT.total_wire_debits_amount IS 'Total Wire debits ($) to all accounts for the party during the period.'
;


CREATE SET TABLE AMLCTR.FSK_RISK_ASSESSMENT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      risk_assessment_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      risk_assessment_status_code CHAR(3) NOT NULL,
      risk_classification DECIMAL(1,0),
      proposed_risk_classification DECIMAL(1,0),
      party_number VARCHAR(50) NOT NULL,
      party_key DECIMAL(10,0),
      party_name VARCHAR(35),
      user_id DECIMAL(10,0) NOT NULL,
      group_id DECIMAL(10,0) NOT NULL,
      starting_month_key DECIMAL(6,0),
      risk_assessment_duration DECIMAL(3,0) NOT NULL,
      create_date TIMESTAMP(6) NOT NULL,
      create_user_id VARCHAR(35) NOT NULL,
      opened_ind CHAR(1) NOT NULL,
      employee_ind CHAR(1),
      version_number DECIMAL(10,0) NOT NULL,
      logical_delete_ind CHAR(1) NOT NULL)
UNIQUE PRIMARY INDEX PK_RISK_ASS ( risk_assessment_id ,segment_id )
INDEX XIE5FSK_RISK_ASS ( party_key )
INDEX XIE7FSK_RISK_ASS ( user_id )
INDEX XIE8FSK_RISK_ASS ( group_id )
INDEX XIE9FSK_RISK_ASS ( party_number );


COMMENT ON TABLE AMLCTR.FSK_RISK_ASSESSMENT IS 'Details of a potentially suspicious entity identified as a result of scenarios and risk factors triggering.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT.risk_assessment_id IS 'System generated synthetic/surrogate key that uniquely identifies a risk assessment record.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT.risk_assessment_status_code IS 'Status: Active (ACT), Closed(CLS), Checked Out (OUT)'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT.risk_classification IS 'The risk_classification that the party had prior to this assessment.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT.party_number IS 'Natural key of primary entity (party, account, hhld) associated with the risk assessment record.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT.party_key IS 'Surrogate key of primary entity (party, account, hhld) associated with the risk assessment record'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT.user_id IS 'Which user the risk assessment record is assigned to.

If not used, value = -1.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT.group_id IS 'Which group the risk assessment record is assigned to.

If not used, value = -1.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT.starting_month_key IS 'Which batch asof date the assessment was generated from.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT.risk_assessment_duration IS 'Number of months of risk_classifier_fact data that were considered in producing this risk_classification value.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT.create_date IS 'When the RA record was created'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT.create_user_id IS 'User who inserted the record into the database.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT.opened_ind IS 'Has this risk assessment record been opened or actioned by anyone since creation (Y/N).'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT.employee_ind IS 'Is the entity of interest an employee of the client. Y/N'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT.version_number IS 'Used to implement optimistic locking.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT.logical_delete_ind IS 'Has the record been logically deleted. Y/N'
;

CREATE SET TABLE AMLCTR.FSK_RISK_ASSESSMENT_CLASSIFIER ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      risk_assessment_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      risk_classifier_id DECIMAL(10,0) NOT NULL, 
CONSTRAINT R_95 FOREIGN KEY ( risk_assessment_id ,segment_id ) REFERENCES AMLCTR.FSK_RISK_ASSESSMENT ( risk_assessment_id ,
segment_id ),
CONSTRAINT R_97 FOREIGN KEY ( segment_id ,risk_classifier_id ) REFERENCES AMLCTR.FSK_RISK_CLASSIFIER ( segment_id ,
risk_classifier_id ))
UNIQUE PRIMARY INDEX XPKFSK_RISK_ASSESSMENT_CLASSIF ( risk_assessment_id ,
segment_id ,risk_classifier_id );


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_CLASSIFIER.risk_assessment_id IS 'System generated synthetic/surrogate key that uniquely identifies a risk assessment record.'
;

CREATE SET TABLE AMLCTR.FSK_RISK_ASSESSMENT_COMMENT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      comment_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      risk_assessment_id DECIMAL(10,0) NOT NULL,
      assessment_comment_text VARCHAR(2000) NOT NULL,
      create_date TIMESTAMP(6) NOT NULL,
      create_user_id VARCHAR(35) NOT NULL,
      logical_delete_ind CHAR(1) NOT NULL, 
CONSTRAINT FK_RISK_ASS_COMMENT_ALERT FOREIGN KEY ( segment_id ,
risk_assessment_id ) REFERENCES AMLCTR.FSK_RISK_ASSESSMENT ( segment_id ,
risk_assessment_id ))
UNIQUE PRIMARY INDEX PK_RISK_ASS_COMMENT ( comment_id ,segment_id );


COMMENT ON TABLE AMLCTR.FSK_RISK_ASSESSMENT_COMMENT IS 'Details of user comments added to the alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_COMMENT.comment_id IS 'Unique system generated synthetic key used to uniquely identify an alert comment.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_COMMENT.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_COMMENT.risk_assessment_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.

'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_COMMENT.assessment_comment_text IS 'Freeform text comment.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_COMMENT.create_date IS 'Date the comment was added to the alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_COMMENT.create_user_id IS 'Which user added the comment.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_COMMENT.logical_delete_ind IS 'Has the record been logically deleted. Y/N'
;

CREATE SET TABLE AMLCTR.FSK_RISK_ASSESSMENT_DOCUMENT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      document_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      risk_assessment_id DECIMAL(10,0) NOT NULL,
      document_name VARCHAR(255) NOT NULL,
      document_mime_type_desc VARCHAR(255) NOT NULL,
      document_location_desc VARCHAR(2000) NOT NULL,
      document_file_name VARCHAR(255) NOT NULL,
      document_desc VARCHAR(255),
      create_date TIMESTAMP(6) NOT NULL,
      create_user_id VARCHAR(35) NOT NULL,
      logical_delete_ind CHAR(1) NOT NULL, 
CONSTRAINT FK_RISK_ASS_DOCUMENT_ALERT FOREIGN KEY ( segment_id ,
risk_assessment_id ) REFERENCES AMLCTR.FSK_RISK_ASSESSMENT ( segment_id ,
risk_assessment_id ))
UNIQUE PRIMARY INDEX PK_RISK_ASS_DOCUMENT ( document_id ,segment_id );


COMMENT ON TABLE AMLCTR.FSK_RISK_ASSESSMENT_DOCUMENT IS 'Details of user documents added to the alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_DOCUMENT.document_id IS 'Unique system generated synthetic identifier for  an alert document.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_DOCUMENT.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_DOCUMENT.risk_assessment_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_DOCUMENT.document_name IS 'English name for the document.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_DOCUMENT.document_mime_type_desc IS 'mime type e.g. Word, Excel.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_DOCUMENT.document_location_desc IS 'Document path.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_DOCUMENT.document_file_name IS 'Document file name.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_DOCUMENT.document_desc IS 'Free form user-added description.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_DOCUMENT.create_date IS 'Date the document was added to the alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_DOCUMENT.create_user_id IS 'Which user added the document.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_DOCUMENT.logical_delete_ind IS 'Has the record been logically deleted. Y/N'
;


CREATE SET TABLE AMLCTR.FSK_RISK_ASSESSMENT_EMAIL ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      email_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      risk_assessment_id DECIMAL(10,0) NOT NULL,
      email_to_text VARCHAR(2000) NOT NULL,
      email_cc_text VARCHAR(2000),
      email_subject_desc VARCHAR(255),
      email_message_text VARCHAR(4000),
      create_date TIMESTAMP(6) NOT NULL,
      create_user_id VARCHAR(35) NOT NULL, 
CONSTRAINT FK_RISK_ASS_EMAIL_ALERT FOREIGN KEY ( segment_id ,
risk_assessment_id ) REFERENCES AMLCTR.FSK_RISK_ASSESSMENT ( segment_id ,
risk_assessment_id ))
UNIQUE PRIMARY INDEX PK_RISK_ASS_EMAIL ( email_id ,segment_id );

COMMENT ON TABLE AMLCTR.FSK_RISK_ASSESSMENT_EMAIL IS 'Details of any e-mails sent regarding the alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_EMAIL.email_id IS 'Unique system generated synthetic key used to uniquely identify an alert email.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_EMAIL.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_EMAIL.risk_assessment_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_EMAIL.email_to_text IS 'Who the email was sent to.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_EMAIL.email_cc_text IS 'Who was cc''d on the e-mail.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_EMAIL.email_subject_desc IS 'e-mail subject'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_EMAIL.email_message_text IS 'e-mail body'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_EMAIL.create_date IS 'Date the e-mail was added to the alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_EMAIL.create_user_id IS 'Which user added the e-mail to the alert.'
;

CREATE SET TABLE AMLCTR.FSK_RISK_ASSESSMENT_EVENT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      event_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      risk_assessment_id DECIMAL(10,0) NOT NULL,
      event_type_code CHAR(3) NOT NULL,
      event_desc VARCHAR(255),
      create_date TIMESTAMP(6) NOT NULL,
      create_user_id VARCHAR(35) NOT NULL, 
CONSTRAINT FK_RISK_ASS_EVENT_ALERT FOREIGN KEY ( segment_id ,
risk_assessment_id ) REFERENCES AMLCTR.FSK_RISK_ASSESSMENT ( segment_id ,
risk_assessment_id ))
UNIQUE PRIMARY INDEX PK_RISK_ASS_EVENT ( event_id ,segment_id );


COMMENT ON TABLE AMLCTR.FSK_RISK_ASSESSMENT_EVENT IS 'Details of all actions taken on the alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_EVENT.event_id IS 'A system generated synthetic key used to uniquely identify an instance of an alert event.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_EVENT.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_EVENT.risk_assessment_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_EVENT.event_type_code IS 'Describes whether the event was for example: "Alert Checked In", "Alert Checked Out" etc.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_EVENT.event_desc IS 'Free-form description of the event.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_EVENT.create_date IS 'Date the record was created.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_ASSESSMENT_EVENT.create_user_id IS 'Who created the record.'
;

CREATE SET TABLE AMLCTR.FSK_RISK_CLASSIFIER ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      risk_classifier_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      risk_classifier_name VARCHAR(35) NOT NULL,
      risk_classifier_short_desc VARCHAR(35),
      risk_classifier_desc VARCHAR(255),
      risk_classifier_type_code CHAR(3),
      active_ind CHAR(1),
      weight DECIMAL(10,0) NOT NULL,
      source_table VARCHAR(35),
      source_column VARCHAR(30),
      source_value CHAR(1),
      classifier_fact_column VARCHAR(30),
      operator_desc VARCHAR(3),
      locked_ind CHAR(1),
      classifier_threshold DECIMAL(10,0),
      risk_classifier_category_id DECIMAL(10,0),
      list_id DECIMAL(10,0),
      create_date TIMESTAMP(6),
      create_user_id VARCHAR(35),
      end_date TIMESTAMP(6),
      end_user_id VARCHAR(35),
      version_number DECIMAL(5,0),
      current_ind CHAR(1) NOT NULL,
      logical_delete_ind CHAR(1), 
CONSTRAINT R_79 FOREIGN KEY ( segment_id ,risk_classifier_category_id ) REFERENCES AMLCTR.FSK_RISK_CLASSIFIER_CATEGORY ( segment_id ,
risk_classifier_category_id ),
CONSTRAINT R_80 FOREIGN KEY ( segment_id ,list_id ) REFERENCES AMLCTR.FSK_LIST ( segment_id ,
list_id ))
UNIQUE PRIMARY INDEX XPKFSK_RISK_CLASSIFIER ( risk_classifier_id ,
segment_id );


COMMENT ON COLUMN AMLCTR.FSK_RISK_CLASSIFIER.risk_classifier_name IS 'Short, non-descriptive name like SASRC001.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_CLASSIFIER.risk_classifier_type_code IS 'Type of classifier. descriptions are in fsk_lov under lov_type_name = ''RC TYPE''.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_CLASSIFIER.active_ind IS 'Whether or not this classifier should be included in the next risk classification module execution.

The value of this column may be changed by the customer, even if the classifier is locked.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_CLASSIFIER.weight IS 'The value of this column may be changed by the customer, even if the classifier is locked.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_CLASSIFIER.source_table IS 'Entity Level for this classifier. Note that this is restricted to ACC, PTY, PPF or NONE. Household classifiers are not allowed.

ACC | PTY |  OTH | PPF - use fsk_lov to match these to a specific table fsc_account_dim | fsc_party_dim | fsc_party_profile_'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_CLASSIFIER.source_column IS 'Only for Risk Classifiers that have no lists (RC type 4 and 5). Column will be NULL otherwise.

The value of this column may be changed by the customer, even if the classifier is locked.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_CLASSIFIER.source_value IS 'Y|N

Populated only for type 4 and 5 classifiers.

For type 4, where the classifier is checking an indicator field, this column specifies the value that the classifier should consider a hit.
'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_CLASSIFIER.operator_desc IS 'RC Types 4 and 5 only.

The value of this column may be changed by the customer, even if the classifier is locked.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_CLASSIFIER.locked_ind IS '(Y | N) Whether or not the classifer is locked. SAS ships approximately 30 "built-in" risk classifiers. The fsk_risk_classifier records associated with them are locked. If a classifier is locked then the user cannot change the values of certain columns th'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_CLASSIFIER.classifier_threshold IS 'Only used for classifer types 3, 4, and 5. NULL for types 1 and 2. 

The value of this column may be changed by the customer, even if the classifier is locked.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_CLASSIFIER.list_id IS 'System generated synthetic/surrogate key that uniquely identifies a risk list.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_CLASSIFIER.version_number IS 'Tracks how many versions of the scenario have been created. The record with the maximum number will always be the current record.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_CLASSIFIER.current_ind IS 'Y|N Whether or not this is the current version of the fsk_risk_classifier record. When changes are made to a risk classifier through the UI, the old version of the record is retained for audit purposes. The current_ind will always be Y for the record with'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_CLASSIFIER.logical_delete_ind IS 'Has this row been logically deleted Y/N. Logically deleted records are kept in the database for audit purposes but are not displayed by the UI at all. In version 2.2, it is not possible to delete a risk classifier via the UI. The UI can only make classifi'
;

CREATE SET TABLE AMLCTR.FSK_RISK_CLASSIFIER_CATEGORY ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      risk_classifier_category_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      risk_classifier_category_name VARCHAR(35),
      risk_classifier_category_desc VARCHAR(255),
      create_date TIMESTAMP(6),
      create_user_id VARCHAR(35),
      delete_date TIMESTAMP(6),
      delete_user_id VARCHAR(35),
      logical_delete_ind CHAR(1) NOT NULL DEFAULT 'N')
UNIQUE PRIMARY INDEX XPKFSK_RISK_CLASSIFIER_CATEGOR ( risk_classifier_category_id ,
segment_id );


COMMENT ON TABLE AMLCTR.FSK_RISK_CLASSIFIER_CATEGORY IS 'Allows user to create groups of related categories.'
;


COMMENT ON COLUMN AMLCTR.FSK_RISK_CLASSIFIER_CATEGORY.logical_delete_ind IS 'Has this row been logically deleted Y/N'
;

CREATE SET TABLE AMLCTR.FSK_ROUTING_CONSTRAINT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      routing_group_id DECIMAL(10,0) NOT NULL,
      routing_rule_id DECIMAL(3,0) NOT NULL,
      constraint_sequence_number DECIMAL(2,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      column_name VARCHAR(35),
      operator_desc CHAR(3),
      value_desc VARCHAR(35),
      compound_operator_name CHAR(4), 
CONSTRAINT R_55 FOREIGN KEY ( routing_group_id ,routing_rule_id ,
segment_id ) REFERENCES AMLCTR.FSK_ROUTING_RULE ( routing_group_id ,
routing_rule_id ,segment_id ))
UNIQUE PRIMARY INDEX XPKFSK_ROUTING_CONSTRAINT ( routing_group_id ,
routing_rule_id ,constraint_sequence_number ,segment_id );


COMMENT ON TABLE AMLCTR.FSK_ROUTING_CONSTRAINT IS 'A specific constraint within a rule used to determine initial routing of an alert.  e.g. money_laundering_risk_score > 700.'
;


COMMENT ON COLUMN AMLCTR.FSK_ROUTING_CONSTRAINT.routing_group_id IS 'Unique identifier.'
;


COMMENT ON COLUMN AMLCTR.FSK_ROUTING_CONSTRAINT.routing_rule_id IS 'Unique identifier within routing_group_id to identify a rule.'
;


COMMENT ON COLUMN AMLCTR.FSK_ROUTING_CONSTRAINT.constraint_sequence_number IS 'Unique sequence number within routing_group_id and routing_rule_id used to identify a specific constraint.'
;


COMMENT ON COLUMN AMLCTR.FSK_ROUTING_CONSTRAINT.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_ROUTING_CONSTRAINT.column_name IS 'Name of a column in FSK_ALERT on which to constrain.'
;


COMMENT ON COLUMN AMLCTR.FSK_ROUTING_CONSTRAINT.operator_desc IS 'The logical operator forming the constraint. e.g. > or <.'
;


COMMENT ON COLUMN AMLCTR.FSK_ROUTING_CONSTRAINT.value_desc IS 'The value to compare the column against.'
;


COMMENT ON COLUMN AMLCTR.FSK_ROUTING_CONSTRAINT.compound_operator_name IS 'The operator used to combine constraints within a rule.'
;

CREATE SET TABLE AMLCTR.FSK_ROUTING_GROUP ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      routing_group_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      routing_group_name VARCHAR(50) NOT NULL,
      logical_delete_ind CHAR(1) NOT NULL)
UNIQUE PRIMARY INDEX XPKFSK_ROUTING_GROUP ( routing_group_id ,
segment_id );


COMMENT ON TABLE AMLCTR.FSK_ROUTING_GROUP IS 'A collection of user-defined routing rules that determine how an alert should initially be routed.'
;


COMMENT ON COLUMN AMLCTR.FSK_ROUTING_GROUP.routing_group_id IS 'Unique identifier.'
;


COMMENT ON COLUMN AMLCTR.FSK_ROUTING_GROUP.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_ROUTING_GROUP.routing_group_name IS 'Unique name for the group.'
;


COMMENT ON COLUMN AMLCTR.FSK_ROUTING_GROUP.logical_delete_ind IS 'Has this record been logically deleted Y/N.'
;


CREATE SET TABLE AMLCTR.FSK_ROUTING_RULE ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      routing_group_id DECIMAL(10,0) NOT NULL,
      routing_rule_id DECIMAL(3,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      route_priority_number DECIMAL(3,0),
      route_type_code DECIMAL(1,0),
      initial_route_id DECIMAL(10,0), 
CONSTRAINT R_64 FOREIGN KEY ( routing_group_id ,segment_id ) REFERENCES AMLCTR.FSK_ROUTING_GROUP ( routing_group_id ,
segment_id ))
UNIQUE PRIMARY INDEX XPKFSK_ROUTING_RULE ( routing_group_id ,
routing_rule_id ,segment_id );


COMMENT ON TABLE AMLCTR.FSK_ROUTING_RULE IS 'A set of constraints forming a rule to govern the initial routing of an alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_ROUTING_RULE.routing_group_id IS 'Unique identifier.'
;


COMMENT ON COLUMN AMLCTR.FSK_ROUTING_RULE.routing_rule_id IS 'Unique identifier within routing_group_id to identify a rule.'
;


COMMENT ON COLUMN AMLCTR.FSK_ROUTING_RULE.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_ROUTING_RULE.route_priority_number IS 'A prioritization of rule execution.  Higher priorities take precedence over lower.'
;


COMMENT ON COLUMN AMLCTR.FSK_ROUTING_RULE.route_type_code IS 'Is the alert being routed to a group ("0") or to a user ("1").'
;


COMMENT ON COLUMN AMLCTR.FSK_ROUTING_RULE.initial_route_id IS 'The ID of the user or group for initial routing.'
;

CREATE SET TABLE AMLCTR.FSK_SCENARIO ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      scenario_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      header_id DECIMAL(10,0) NOT NULL,
      scenario_name VARCHAR(35) NOT NULL,
      scenario_short_description VARCHAR(100) NOT NULL,
      scenario_description VARCHAR(255) NOT NULL,
      scenario_category_code CHAR(3) NOT NULL,
      scenario_code_location_desc VARCHAR(255) NOT NULL,
      product_type_code CHAR(3) NOT NULL,
      scenario_status_code CHAR(3) NOT NULL,
      scenario_run_frequency_desc VARCHAR(25) NOT NULL,
      current_ind CHAR(1) NOT NULL,
      initial_route_id DECIMAL(10,0) NOT NULL,
      route_type_code DECIMAL(1,0) NOT NULL,
      dflt_suppress_duration_count DECIMAL(8,0) NOT NULL,
      scenario_duration_count DECIMAL(8,0) NOT NULL,
      money_laundering_bayes_weight DECIMAL(15,5) NOT NULL,
      terror_financing_bayes_weight DECIMAL(15,5),
      execution_probability_rate DECIMAL(7,7) NOT NULL,
      risk_factor_ind CHAR(1),
      create_date TIMESTAMP(6) NOT NULL,
      create_user_id VARCHAR(35) NOT NULL,
      end_date TIMESTAMP(6) NOT NULL DEFAULT TIMESTAMP '5999-01-01 00:00:00.000000',
      end_user_id VARCHAR(35),
      version_number DECIMAL(5,0) NOT NULL,
      logical_delete_ind CHAR(1) NOT NULL,
      routing_group_id DECIMAL(10,0), 
CONSTRAINT FK_SCENARIO_HEADER FOREIGN KEY ( segment_id ,header_id ) REFERENCES AMLCTR.FSK_HEADER ( segment_id ,
header_id ),
CONSTRAINT R_66 FOREIGN KEY ( segment_id ,routing_group_id ) REFERENCES AMLCTR.FSK_ROUTING_GROUP ( segment_id ,
routing_group_id ))
UNIQUE PRIMARY INDEX PK_SCENARIO ( scenario_id ,segment_id );


COMMENT ON TABLE AMLCTR.FSK_SCENARIO IS 'A set of logic and parameters used to identify suspicious financial activity.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.scenario_id IS 'Synthetic unique identifier of Scenarios.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.header_id IS 'Name and identifier of the header.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.scenario_name IS 'Short, non-descriptive name like SAS0001.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.scenario_short_description IS 'Abbreviated description'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.scenario_description IS 'Freeform description of the Scenario e.g. "Customer makes multiple cash deposits between $8K and $10K and subsequently wires money to a foreign country."'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.scenario_category_code IS 'Scenario classification: e.g. ATM, CSH, DOR.  See FSK_LOV for values.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.scenario_code_location_desc IS 'Path and filename of code used to run the scenario.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.product_type_code IS 'Product that the scenario is defined for:  e.g. AML-Anti-Money Laundering, SUR-Surveillance'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.scenario_status_code IS 'What state the scenario is in:
ACT- Active
INA - Inactive'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.scenario_run_frequency_desc IS 'How often the scenario runs: Daily,Weekly, Monthly

Values configured in XML file - not in LOV.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.current_ind IS 'Is this the latest version of the scenario Y/N.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.initial_route_id IS 'Which user/group alerts for this scenario get routed to by default.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.route_type_code IS 'Initial Route is to 1-"User" or 0-"Group".'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.dflt_suppress_duration_count IS 'If an alert is triggered don''t re-trigger that alert for the same entity for this many days.

-1 = indefinite'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.scenario_duration_count IS 'Query back over this many days to determine if the alert will be triggered.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.money_laundering_bayes_weight IS 'Number used to weight money laundering scenarios in the risk ranking process.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.terror_financing_bayes_weight IS 'Number used to weight terrorist financing scenarios in the risk ranking process.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.execution_probability_rate IS 'Used in Risk Ranking. 0 < x < 1'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.risk_factor_ind IS 'Is this a risk factor scenario Y/N'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.create_date IS 'Date the scenario was entered into the database.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.create_user_id IS 'User who created the scenario.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.end_date IS 'Date the scenario became inactive.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.end_user_id IS 'User that deactivated the scenario.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.version_number IS 'Tracks how many versions of the scenario have been created.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.logical_delete_ind IS 'Has this record been logically deleted Y/N.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO.routing_group_id IS 'Unique identifier.'
;

CREATE SET TABLE AMLCTR.FSK_SCENARIO_PARAMETER ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      scenario_id DECIMAL(10,0) NOT NULL,
      parm_name VARCHAR(35) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      parm_value VARCHAR(1024) NOT NULL,
      parm_type_desc VARCHAR(20) NOT NULL,
      parm_desc VARCHAR(255) NOT NULL, 
CONSTRAINT FK_SCENARIO_PARAMETER_SCENARIO FOREIGN KEY ( scenario_id ,
segment_id ) REFERENCES AMLCTR.FSK_SCENARIO ( scenario_id ,segment_id ))
UNIQUE PRIMARY INDEX PK_SCENARIO_PARAMETER ( scenario_id ,parm_name ,
segment_id );

COMMENT ON TABLE AMLCTR.FSK_SCENARIO_PARAMETER IS 'Details of parameters used in the scenario.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO_PARAMETER.scenario_id IS 'Synthtic key used to uniquely identify a rule.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO_PARAMETER.parm_name IS 'Label used to define a rule parameter e.g. DURATION.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO_PARAMETER.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO_PARAMETER.parm_value IS 'The value used for the given parameter for this rule execution.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO_PARAMETER.parm_type_desc IS 'Parameters can be specified in three forms: Constant, Variable, or List.'
;


COMMENT ON COLUMN AMLCTR.FSK_SCENARIO_PARAMETER.parm_desc IS 'Freeform description of the parameter.'
;


CREATE SET TABLE AMLCTR.FSK_SEQUENCE ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      next_sequence_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER )
PRIMARY INDEX ( next_sequence_id );


COMMENT ON TABLE AMLCTR.FSK_SEQUENCE IS 'Used to generate unique identifiers for various tables.'
;


COMMENT ON COLUMN AMLCTR.FSK_SEQUENCE.next_sequence_id IS 'The next identifier available to be used.  The user should read this value and immediately increment, update and commit to allow the next user access.'
;


COMMENT ON COLUMN AMLCTR.FSK_SEQUENCE.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;

CREATE SET TABLE AMLCTR.FSK_TRANSACTION_ALERT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      alert_id DECIMAL(10,0) NOT NULL,
      transaction_key DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      date_key DECIMAL(8,0) NOT NULL,
      transaction_reference_number VARCHAR(50) NOT NULL,
      transaction_description VARCHAR(255),
      security_name VARCHAR(35),
      deal_number VARCHAR(35))
UNIQUE PRIMARY INDEX XPKFSK_TRANSACTION_AL ( alert_id ,transaction_key ,
segment_id )
INDEX XIE1FSK_TRANSACTION_AL ( transaction_reference_number )
INDEX XIE2FSK_TRANSACTION_AL ( date_key )
INDEX XIE3FSK_TRANSACTION_AL ( transaction_key );


COMMENT ON TABLE AMLCTR.FSK_TRANSACTION_ALERT IS 'A supplementary table to the transaction facts used to capture additional, typically verbose, data that about a transaction.  Storing this data here helps keep the fact table "skinny" and therefore smaller than they would otherwise be.'
;


COMMENT ON COLUMN AMLCTR.FSK_TRANSACTION_ALERT.alert_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.'
;


COMMENT ON COLUMN AMLCTR.FSK_TRANSACTION_ALERT.transaction_key IS 'Surrogate key..'
;


COMMENT ON COLUMN AMLCTR.FSK_TRANSACTION_ALERT.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_TRANSACTION_ALERT.date_key IS 'Note: this is normally a system-generated surrogate key, but for performance reasons we are using a numeric form of the date:

yyyymmdd

This column has been added to this table to enable table partitioning.'
;


COMMENT ON COLUMN AMLCTR.FSK_TRANSACTION_ALERT.transaction_reference_number IS 'Source system''s transaction identifier e.g. deposit number'
;


COMMENT ON COLUMN AMLCTR.FSK_TRANSACTION_ALERT.transaction_description IS 'Free form text description of trade.'
;


COMMENT ON COLUMN AMLCTR.FSK_TRANSACTION_ALERT.security_name IS 'Name of the equity, bond, currency etc bought or sold.  Could use ticker if preferred.'
;


COMMENT ON COLUMN AMLCTR.FSK_TRANSACTION_ALERT.deal_number IS 'Number identifying a trade plus associated settlements.  e.g. Trade is to buy 1mm Euros; settled with two wires each of $500K.  All three transactions are part of the same deal and therefore will have the same deal number.'
;

CREATE SET TABLE AMLCTR.FSK_UI_AVAILABILITY ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      ui_availability_ind CHAR(1) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER )
PRIMARY INDEX ( ui_availability_ind );

COMMENT ON TABLE AMLCTR.FSK_UI_AVAILABILITY IS 'Used to indicate if the user interface is available - meaning the batch run has finished and it is now safe to use the application.'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_AVAILABILITY.ui_availability_ind IS 'Is the user interface available for use Y/N.'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_AVAILABILITY.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


CREATE SET TABLE AMLCTR.FSK_UI_COLUMN ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      table_ui_name VARCHAR(35) NOT NULL,
      column_ui_name VARCHAR(35) NOT NULL,
      group_ui_name VARCHAR(35) NOT NULL,
      column_expression_text VARCHAR(255),
      column_label_desc VARCHAR(64),
      column_position_number DECIMAL(5,0),
      format_code CHAR(3),
      format_modifier_text VARCHAR(1024),
      column_display_level_code CHAR(3),
      column_search_level_code CHAR(3),
      sorted_by_position_number DECIMAL(5,0),
      column_active_ind CHAR(1),
      local_key_db_name VARCHAR(35),
      remote_key_db_name VARCHAR(35),
      remote_table_ui_name VARCHAR(35))
UNIQUE PRIMARY INDEX XPKFSK_UI_COLUMN ( table_ui_name ,column_ui_name );


COMMENT ON TABLE AMLCTR.FSK_UI_COLUMN IS 'Describes columns in each table/view that can be displayed using the UI metadata driven screens.'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_COLUMN.table_ui_name IS 'Name of the table in which this column resides.'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_COLUMN.column_ui_name IS 'Column name.'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_COLUMN.group_ui_name IS 'Name of the group in which this column is displayed.'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_COLUMN.column_expression_text IS 'The physical column name or SQL statement used to get the data.'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_COLUMN.column_label_desc IS 'Readable version of column name for display on screen.'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_COLUMN.column_position_number IS 'Which position in the group the column is displayed.'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_COLUMN.format_code IS 'How to format the column data.'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_COLUMN.format_modifier_text IS 'Modifier for format code.'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_COLUMN.column_display_level_code IS '"LIT" - Light - Display on the main or basic elements of a table e.g. acct #, name and address

"BAS" - Basic - Display all of the elements of a table except the technical elements.

"EXT" - Extended - Display all of the elements of a table including '
;


COMMENT ON COLUMN AMLCTR.FSK_UI_COLUMN.column_search_level_code IS 'Level at which this column appears in the column list on the Advanced Query tab (LIT/BAS/EXT).'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_COLUMN.sorted_by_position_number IS 'Position of column in ORDER BY clause (negative means DESC sort) for the initial display of this table.'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_COLUMN.column_active_ind IS 'Is this column still active (Y/N)'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_COLUMN.local_key_db_name IS 'Name of the column in this table to use to join this table to the remote table containing the value.'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_COLUMN.remote_key_db_name IS 'Name of column in remote table to use to join the remote table containing the value to this table.'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_COLUMN.remote_table_ui_name IS 'Name of the remote table containing remote_key_db_name.'
;

CREATE SET TABLE AMLCTR.FSK_UI_GROUP ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      group_ui_name VARCHAR(35) NOT NULL,
      group_label_desc VARCHAR(64),
      group_position_number DECIMAL(5,0))
UNIQUE PRIMARY INDEX ( group_ui_name );

COMMENT ON TABLE AMLCTR.FSK_UI_GROUP IS 'Describes sections of screens where various columns should be displayed.'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_GROUP.group_ui_name IS 'Group name.'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_GROUP.group_label_desc IS 'Readable version of gorup name.'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_GROUP.group_position_number IS 'Which order to display the group on the screen.'
;

CREATE SET TABLE AMLCTR.FSK_UI_TABLE ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      table_ui_name VARCHAR(35) NOT NULL,
      table_expression_text VARCHAR(2000),
      table_label_desc VARCHAR(64),
      table_data_source_code CHAR(3),
      table_search_level_code CHAR(3),
      table_active_ind CHAR(1))
UNIQUE PRIMARY INDEX ( table_ui_name );


COMMENT ON TABLE AMLCTR.FSK_UI_TABLE IS 'Describes table/view that can be displayed using the UI metadata driven screens.'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_TABLE.table_ui_name IS 'The name of the table.'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_TABLE.table_expression_text IS 'Physical table name or SQL statement used to get the table.'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_TABLE.table_label_desc IS 'Readable table name for display on the screen.'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_TABLE.table_data_source_code IS 'Values: COR or CTR'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_TABLE.table_search_level_code IS 'Level of information needed to display this table in the search query builder (LIT/BAS/EXT).'
;


COMMENT ON COLUMN AMLCTR.FSK_UI_TABLE.table_active_ind IS 'Is this table still active (Y/N) i.e. is it available to be displayed.'
;

CREATE SET TABLE AMLCTR.FSK_USER ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      user_id DECIMAL(10,0) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      user_long_id VARCHAR(35) NOT NULL,
      display_name VARCHAR(35) NOT NULL,
      email_address VARCHAR(255) NOT NULL,
      user_privileges_code DECIMAL(18,0),
      starting_tab_pref VARCHAR(35),
      alert_rows_displayed_pref DECIMAL(4,0),
      query_rows_displayed_pref DECIMAL(4,0),
      assessmnt_rows_displayed_pref DECIMAL(4,0),
      trans_rows_displayed_pref DECIMAL(4,0),
      manager_id DECIMAL(10,0),
      administrator_ind CHAR(1),
      version_number DECIMAL(10,0) NOT NULL,
      logical_delete_ind CHAR(1) NOT NULL)
UNIQUE PRIMARY INDEX PK_USER ( user_id ,segment_id );


COMMENT ON TABLE AMLCTR.FSK_USER IS 'Provides details and privileges for authorized users of the system.'
;


COMMENT ON COLUMN AMLCTR.FSK_USER.user_id IS 'System generated identifier'
;


COMMENT ON COLUMN AMLCTR.FSK_USER.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN AMLCTR.FSK_USER.user_long_id IS 'Source systems user id e.g. kebett'
;


COMMENT ON COLUMN AMLCTR.FSK_USER.display_name IS 'Display name for user e.g. "John Smith"'
;


COMMENT ON COLUMN AMLCTR.FSK_USER.email_address IS 'user email address'
;


COMMENT ON COLUMN AMLCTR.FSK_USER.user_privileges_code IS '1 - User Administration - An agent with this privilege enabled can update the profiles of all users and groups.
2 - Route Alerts - An agent with this privilege enabled can assign alerts to another agent or group. 
4 - Suppress Alerts - An agent with thi'
;


COMMENT ON COLUMN AMLCTR.FSK_USER.manager_id IS 'Which user is the direct supervisor of this user for the purposes of administering this product. FK to user_id (recursive)'
;


COMMENT ON COLUMN AMLCTR.FSK_USER.administrator_ind IS 'Not used in AML 2.1.  Defect to remove in next release.'
;


COMMENT ON COLUMN AMLCTR.FSK_USER.version_number IS 'Used to implement optimistic locking.'
;


COMMENT ON COLUMN AMLCTR.FSK_USER.logical_delete_ind IS 'Has the row been logically deleted Y/N'
;


CREATE VIEW AMLCTR.FSK_ACCOUNT_LIST_VIEW AS 
	SELECT element.list_id,element.list_element_value,list.segment_id
		FROM AMLCTR.FSK_LIST list,AMLCTR.FSK_LIST_ELEMENT element
		WHERE list.list_id = element.list_id
and list.validation_type_code = 'ACC'
and list.logical_delete_ind = 'N'
and element.logical_delete_ind = 'N'
and list.segment_id = element.segment_id
;


COMMENT ON VIEW AMLCTR.FSK_ACCOUNT_LIST_VIEW IS 'Risk list elements for lists that have an validation_type_code of ACC.'
;


CREATE VIEW AMLCTR.FSK_PARTY_LIST_VIEW AS 
	SELECT element.list_id,element.list_element_value,list.segment_id
		FROM AMLCTR.FSK_LIST list,AMLCTR.FSK_LIST_ELEMENT element
		WHERE list.list_id = element.list_id
and list.validation_type_code = 'PTY'
and list.logical_delete_ind = 'N'
and element.logical_delete_ind = 'N'
and list.segment_id = element.segment_id
;


COMMENT ON VIEW AMLCTR.FSK_PARTY_LIST_VIEW IS 'Risk list elements for lists that have an validation_type_code of PTY.'
;


----------------------------------------------------------------------------------------
--Create KC the tables that are replicated in each multibank segment's schema
--Code for two segments (BANK1KCTR and BANK2KCTR) is provided. If additional
--multibank segments are needed then the following statements may be used
--as a template to create objects for them.
----------------------------------------------------------------------------------------
CREATE SET TABLE BANK1KCTR.FSK_ACCOUNT_KEYS_HHD ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      alert_id DECIMAL(10,0) NOT NULL,
      account_key DECIMAL(10,0) NOT NULL,
      run_date TIMESTAMP(6))
PRIMARY INDEX ( alert_id ,account_key );


COMMENT ON TABLE BANK1KCTR.FSK_ACCOUNT_KEYS_HHD IS 'Replication scratch table used to improve replication performance.'
;


COMMENT ON COLUMN BANK1KCTR.FSK_ACCOUNT_KEYS_HHD.alert_id IS 'Uniquely identifies an alert.'
;


COMMENT ON COLUMN BANK1KCTR.FSK_ACCOUNT_KEYS_HHD.account_key IS 'Uniquely identifies an account.'
;


COMMENT ON COLUMN BANK1KCTR.FSK_ACCOUNT_KEYS_HHD.run_date IS 'System run date.'
;


CREATE SET TABLE BANK1KCTR.FSK_ACCOUNT_KEYS_PTY ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      alert_id DECIMAL(10,0) NOT NULL,
      account_key DECIMAL(10,0) NOT NULL,
      run_date TIMESTAMP(6))
PRIMARY INDEX ( alert_id ,account_key );


COMMENT ON TABLE BANK1KCTR.FSK_ACCOUNT_KEYS_PTY IS 'Replication scratch table used to improve replication performance.'
;


COMMENT ON COLUMN BANK1KCTR.FSK_ACCOUNT_KEYS_PTY.alert_id IS 'Uniquely identifies an alert.'
;


COMMENT ON COLUMN BANK1KCTR.FSK_ACCOUNT_KEYS_PTY.account_key IS 'Uniquely identifies an account.'
;


COMMENT ON COLUMN BANK1KCTR.FSK_ACCOUNT_KEYS_PTY.run_date IS 'System run date'
;


CREATE SET TABLE BANK1KCTR.FSK_ALERT_NEIGHBOR ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      alert_id DECIMAL(10,0) NOT NULL,
      target_account_number VARCHAR(50) NOT NULL,
      neighbor_account_number VARCHAR(50) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      distance DECIMAL(4,3))
PRIMARY INDEX ( alert_id )
UNIQUE INDEX XPKFSK_ALERT_NEIGH ( alert_id ,target_account_number ,
neighbor_account_number );


COMMENT ON TABLE BANK1KCTR.FSK_ALERT_NEIGHBOR IS 'For account-based alerts, details of other accounts with similar transaction profiles.'
;


COMMENT ON COLUMN BANK1KCTR.FSK_ALERT_NEIGHBOR.alert_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.'
;


COMMENT ON COLUMN BANK1KCTR.FSK_ALERT_NEIGHBOR.target_account_number IS 'The account number related to the alert.'
;


COMMENT ON COLUMN BANK1KCTR.FSK_ALERT_NEIGHBOR.neighbor_account_number IS 'The number of an account that is considered "close" to the target account.'
;


COMMENT ON COLUMN BANK1KCTR.FSK_ALERT_NEIGHBOR.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN BANK1KCTR.FSK_ALERT_NEIGHBOR.distance IS 'A number representing the distance between the target account and the neigbor. Range: 0 (identical) - 0.001 (distant).'
;

CREATE SET TABLE BANK1KCTR.FSK_EDGE_FACT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      edge_key DECIMAL(10,0) NOT NULL,
      network_key DECIMAL(10,0) NOT NULL,
      edge_type_code CHAR(1) NOT NULL DEFAULT 'U',
      remitter_account_number VARCHAR(101) NOT NULL,
      beneficiary_account_number VARCHAR(101) NOT NULL,
      edge_begin_date TIMESTAMP(6),
      edge_transaction_count DECIMAL(10,0),
      edge_amount DECIMAL(15,5))
PRIMARY INDEX ( edge_key ,network_key );

COMMENT ON TABLE BANK1KCTR.FSK_EDGE_FACT IS 'Describes the flow of funds (the edge) between nodes in a Funds Tracker network.'
;

CREATE SET TABLE BANK1KCTR.FSK_NETWORK_DIM ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      network_key DECIMAL(10,0) NOT NULL,
      node_count DECIMAL(10,0),
      edge_count DECIMAL(10,0),
      transaction_count DECIMAL(10,0),
      network_amount DECIMAL(15,5),
      create_date TIMESTAMP(6))
UNIQUE PRIMARY INDEX ( network_key );

COMMENT ON TABLE BANK1KCTR.FSK_NETWORK_DIM IS 'A collection of cash flows into a Funds Tracker network.'
;


COMMENT ON COLUMN BANK1KCTR.FSK_NETWORK_DIM.node_count IS 'How many nodes (i.e. accounts) are in the network.'
;


COMMENT ON COLUMN BANK1KCTR.FSK_NETWORK_DIM.edge_count IS 'How many edges (i.e. accumulated cash flows) there are between nodes in the entire network.'
;


COMMENT ON COLUMN BANK1KCTR.FSK_NETWORK_DIM.transaction_count IS 'How many total transactions make up the network.'
;


COMMENT ON COLUMN BANK1KCTR.FSK_NETWORK_DIM.network_amount IS 'How much currency is flowing through the network.'
;

CREATE SET TABLE BANK1KCTR.FSK_NN_ENTITY ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      primary_entity_number VARCHAR(76) NOT NULL,
      primary_entity_level_code CHAR(3) NOT NULL,
      alert_id DECIMAL(10,0) NOT NULL)
UNIQUE PRIMARY INDEX ( primary_entity_number ,primary_entity_level_code ,
alert_id );


COMMENT ON COLUMN BANK1KCTR.FSK_NN_ENTITY.primary_entity_number IS 'Natural key of primary entity (party, account, hhld) associated with the alert.'
;


COMMENT ON COLUMN BANK1KCTR.FSK_NN_ENTITY.primary_entity_level_code IS 'ACC, PTY, HHD, ASC, BLT'
;


COMMENT ON COLUMN BANK1KCTR.FSK_NN_ENTITY.alert_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.'
;

CREATE SET TABLE BANK1KCTR.FSK_NN_PARTY ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      alert_id DECIMAL(10,0) NOT NULL,
      party_number VARCHAR(76) NOT NULL)
UNIQUE PRIMARY INDEX ( alert_id ,party_number );

COMMENT ON COLUMN BANK1KCTR.FSK_NN_PARTY.alert_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.'
;


COMMENT ON COLUMN BANK1KCTR.FSK_NN_PARTY.party_number IS 'Party Number'
;


CREATE SET TABLE BANK1KCTR.FSK_NODE_FACT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      node_key DECIMAL(10,0) NOT NULL,
      network_key DECIMAL(10,0) NOT NULL,
      account_number VARCHAR(101))
PRIMARY INDEX ( node_key )
UNIQUE INDEX XPKFSK_NODE_FACT ( node_key ,network_key );


COMMENT ON TABLE BANK1KCTR.FSK_NODE_FACT IS 'Describes a single node (i.e. account) in a Funds Tracker network.'
;

CREATE SET TABLE BANK1KCTR.FSK_REPLICATION_DATES ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      alert_id DECIMAL(10,0) NOT NULL,
      start_date TIMESTAMP(6),
      start_date_key DECIMAL(8,0))
PRIMARY INDEX ( alert_id );


COMMENT ON TABLE BANK1KCTR.FSK_REPLICATION_DATES IS 'Replication scratch table used to improve replication performance.'
;


COMMENT ON COLUMN BANK1KCTR.FSK_REPLICATION_DATES.alert_id IS 'Uniquely identifies an alert.'
;


COMMENT ON COLUMN BANK1KCTR.FSK_REPLICATION_DATES.start_date IS 'Replication start date.'
;


COMMENT ON COLUMN BANK1KCTR.FSK_REPLICATION_DATES.start_date_key IS 'Replication start date key.'
;

CREATE SET TABLE BANK1KCTR.FSK_TEMP_NUMBER ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      primary_entity_number VARCHAR(50) NOT NULL)
PRIMARY INDEX ( primary_entity_number );


COMMENT ON TABLE BANK1KCTR.FSK_TEMP_NUMBER IS 'Temporary table used to improve performance.'
;


COMMENT ON COLUMN BANK1KCTR.FSK_TEMP_NUMBER.primary_entity_number IS 'Natural key of entity being processed.'
;




ALTER TABLE BANK1KCTR.FSK_EDGE_FACT
	ADD CONSTRAINT R_173 FOREIGN KEY (network_key) REFERENCES BANK1KCTR.FSK_NETWORK_DIM(network_key)
;



ALTER TABLE BANK1KCTR.FSK_NODE_FACT
	ADD CONSTRAINT R_174 FOREIGN KEY (network_key) REFERENCES BANK1KCTR.FSK_NETWORK_DIM(network_key)
;


CREATE SET TABLE BANK2KCTR.FSK_ACCOUNT_KEYS_HHD ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      alert_id DECIMAL(10,0) NOT NULL,
      account_key DECIMAL(10,0) NOT NULL,
      run_date TIMESTAMP(6))
PRIMARY INDEX ( alert_id ,account_key );


COMMENT ON TABLE BANK2KCTR.FSK_ACCOUNT_KEYS_HHD IS 'Replication scratch table used to improve replication performance.'
;


COMMENT ON COLUMN BANK2KCTR.FSK_ACCOUNT_KEYS_HHD.alert_id IS 'Uniquely identifies an alert.'
;


COMMENT ON COLUMN BANK2KCTR.FSK_ACCOUNT_KEYS_HHD.account_key IS 'Uniquely identifies an account.'
;


COMMENT ON COLUMN BANK2KCTR.FSK_ACCOUNT_KEYS_HHD.run_date IS 'System run date.'
;

CREATE SET TABLE BANK2KCTR.FSK_ACCOUNT_KEYS_PTY ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      alert_id DECIMAL(10,0) NOT NULL,
      account_key DECIMAL(10,0) NOT NULL,
      run_date TIMESTAMP(6))
PRIMARY INDEX ( alert_id ,account_key );


COMMENT ON TABLE BANK2KCTR.FSK_ACCOUNT_KEYS_PTY IS 'Replication scratch table used to improve replication performance.'
;


COMMENT ON COLUMN BANK2KCTR.FSK_ACCOUNT_KEYS_PTY.alert_id IS 'Uniquely identifies an alert.'
;


COMMENT ON COLUMN BANK2KCTR.FSK_ACCOUNT_KEYS_PTY.account_key IS 'Uniquely identifies an account.'
;


COMMENT ON COLUMN BANK2KCTR.FSK_ACCOUNT_KEYS_PTY.run_date IS 'System run date'
;

CREATE SET TABLE BANK2KCTR.FSK_ALERT_NEIGHBOR ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      alert_id DECIMAL(10,0) NOT NULL,
      target_account_number VARCHAR(50) NOT NULL,
      neighbor_account_number VARCHAR(50) NOT NULL,
      segment_id VARCHAR(128) NOT NULL DEFAULT USER ,
      distance DECIMAL(4,3))
PRIMARY INDEX ( alert_id )
UNIQUE INDEX XPKFSK_ALERT_NEIGH ( alert_id ,target_account_number ,
neighbor_account_number );


COMMENT ON TABLE BANK2KCTR.FSK_ALERT_NEIGHBOR IS 'For account-based alerts, details of other accounts with similar transaction profiles.'
;


COMMENT ON COLUMN BANK2KCTR.FSK_ALERT_NEIGHBOR.alert_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.'
;


COMMENT ON COLUMN BANK2KCTR.FSK_ALERT_NEIGHBOR.target_account_number IS 'The account number related to the alert.'
;


COMMENT ON COLUMN BANK2KCTR.FSK_ALERT_NEIGHBOR.neighbor_account_number IS 'The number of an account that is considered "close" to the target account.'
;


COMMENT ON COLUMN BANK2KCTR.FSK_ALERT_NEIGHBOR.segment_id IS 'Multibank configurations use this column to indicate which bank the record belongs to.'
;


COMMENT ON COLUMN BANK2KCTR.FSK_ALERT_NEIGHBOR.distance IS 'A number representing the distance between the target account and the neigbor. Range: 0 (identical) - 0.001 (distant).'
;

CREATE SET TABLE BANK2KCTR.FSK_EDGE_FACT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      edge_key DECIMAL(10,0) NOT NULL,
      network_key DECIMAL(10,0) NOT NULL,
      edge_type_code CHAR(1) NOT NULL DEFAULT 'U',
      remitter_account_number VARCHAR(101) NOT NULL,
      beneficiary_account_number VARCHAR(101) NOT NULL,
      edge_begin_date TIMESTAMP(6),
      edge_transaction_count DECIMAL(10,0),
      edge_amount DECIMAL(15,5))
PRIMARY INDEX ( edge_key ,network_key );

COMMENT ON TABLE BANK2KCTR.FSK_EDGE_FACT IS 'Describes the flow of funds (the edge) between nodes in a Funds Tracker network.'
;

CREATE SET TABLE BANK2KCTR.FSK_NETWORK_DIM ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      network_key DECIMAL(10,0) NOT NULL,
      node_count DECIMAL(10,0),
      edge_count DECIMAL(10,0),
      transaction_count DECIMAL(10,0),
      network_amount DECIMAL(15,5),
      create_date TIMESTAMP(6))
UNIQUE PRIMARY INDEX ( network_key );


COMMENT ON TABLE BANK2KCTR.FSK_NETWORK_DIM IS 'A collection of cash flows into a Funds Tracker network.'
;


COMMENT ON COLUMN BANK2KCTR.FSK_NETWORK_DIM.node_count IS 'How many nodes (i.e. accounts) are in the network.'
;


COMMENT ON COLUMN BANK2KCTR.FSK_NETWORK_DIM.edge_count IS 'How many edges (i.e. accumulated cash flows) there are between nodes in the entire network.'
;


COMMENT ON COLUMN BANK2KCTR.FSK_NETWORK_DIM.transaction_count IS 'How many total transactions make up the network.'
;


COMMENT ON COLUMN BANK2KCTR.FSK_NETWORK_DIM.network_amount IS 'How much currency is flowing through the network.'
;


CREATE SET TABLE BANK2KCTR.FSK_NN_ENTITY ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      primary_entity_number VARCHAR(76) NOT NULL,
      primary_entity_level_code CHAR(3) NOT NULL,
      alert_id DECIMAL(10,0) NOT NULL)
UNIQUE PRIMARY INDEX ( primary_entity_number ,primary_entity_level_code ,
alert_id );


COMMENT ON COLUMN BANK2KCTR.FSK_NN_ENTITY.primary_entity_number IS 'Natural key of primary entity (party, account, hhld) associated with the alert.'
;


COMMENT ON COLUMN BANK2KCTR.FSK_NN_ENTITY.primary_entity_level_code IS 'ACC, PTY, HHD, ASC, BLT'
;


COMMENT ON COLUMN BANK2KCTR.FSK_NN_ENTITY.alert_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.'
;


CREATE SET TABLE BANK2KCTR.FSK_NN_PARTY ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      alert_id DECIMAL(10,0) NOT NULL,
      party_number VARCHAR(76) NOT NULL)
UNIQUE PRIMARY INDEX ( alert_id ,party_number );


COMMENT ON COLUMN BANK2KCTR.FSK_NN_PARTY.alert_id IS 'System generated synthetic/surrogate key that uniquely identifies an alert.'
;


COMMENT ON COLUMN BANK2KCTR.FSK_NN_PARTY.party_number IS 'Party Number'
;

CREATE SET TABLE BANK2KCTR.FSK_NODE_FACT ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      node_key DECIMAL(10,0) NOT NULL,
      network_key DECIMAL(10,0) NOT NULL,
      account_number VARCHAR(101))
PRIMARY INDEX ( node_key )
UNIQUE INDEX XPKFSK_NODE_FACT ( node_key ,network_key );


COMMENT ON TABLE BANK2KCTR.FSK_NODE_FACT IS 'Describes a single node (i.e. account) in a Funds Tracker network.'
;

CREATE SET TABLE BANK2KCTR.FSK_REPLICATION_DATES ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      alert_id DECIMAL(10,0) NOT NULL,
      start_date TIMESTAMP(6),
      start_date_key DECIMAL(8,0))
PRIMARY INDEX ( alert_id );


COMMENT ON TABLE BANK2KCTR.FSK_REPLICATION_DATES IS 'Replication scratch table used to improve replication performance.'
;


COMMENT ON COLUMN BANK2KCTR.FSK_REPLICATION_DATES.alert_id IS 'Uniquely identifies an alert.'
;


COMMENT ON COLUMN BANK2KCTR.FSK_REPLICATION_DATES.start_date IS 'Replication start date.'
;


COMMENT ON COLUMN BANK2KCTR.FSK_REPLICATION_DATES.start_date_key IS 'Replication start date key.'
;

CREATE SET TABLE BANK2KCTR.FSK_TEMP_NUMBER ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      primary_entity_number VARCHAR(50) NOT NULL)
PRIMARY INDEX ( primary_entity_number );


COMMENT ON TABLE BANK2KCTR.FSK_TEMP_NUMBER IS 'Temporary table used to improve performance.'
;


COMMENT ON COLUMN BANK2KCTR.FSK_TEMP_NUMBER.primary_entity_number IS 'Natural key of entity being processed.'
;


ALTER TABLE BANK2KCTR.FSK_EDGE_FACT
	ADD CONSTRAINT R_173 FOREIGN KEY (network_key) REFERENCES BANK2KCTR.FSK_NETWORK_DIM(network_key)
;



ALTER TABLE BANK2KCTR.FSK_NODE_FACT
	ADD CONSTRAINT R_174 FOREIGN KEY (network_key) REFERENCES BANK2KCTR.FSK_NETWORK_DIM(network_key)
;



CREATE SET TABLE AMLCTR.FSK_ERROR_LOG ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      stored_procedure_name VARCHAR(35),
      user_id VARCHAR(10),
      create_date TIMESTAMP(6),
      sql_state VARCHAR(35),
      sql_code VARCHAR(35),
      sql_error_message VARCHAR(256))
PRIMARY INDEX ( stored_procedure_name );

CREATE SET TABLE amlctr.fsk_scenario_status ,NO FALLBACK ,
     NO BEFORE JOURNAL,
     NO AFTER JOURNAL,
     CHECKSUM = DEFAULT
     (
      stored_procedure_name VARCHAR(35),
      userid VARCHAR(10),
      currentdate DATE FORMAT 'YYYY-MM-DD',
      begin_time TIMESTAMP(6),
      end_time TIMESTAMP(6))
PRIMARY INDEX ( stored_procedure_name );



----------------------------------------------------------------------------
--Create Multibank views for KC tables. Additional views will be needed if 
--this script is customized to add additional multibank segments.
----------------------------------------------------------------------------
CREATE VIEW BANK1KCTR.FSK_ACCOUNT_EVENT_ALERT as locking row for access select * from AMLCTR.FSK_ACCOUNT_EVENT_ALERT where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_ACCOUNT_PROFILE_ALERT as locking row for access select * from AMLCTR.FSK_ACCOUNT_PROFILE_ALERT where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_ACCOUNT_TRADE_ALERT as locking row for access select * from AMLCTR.FSK_ACCOUNT_TRADE_ALERT where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_ALERT as locking row for access select * from AMLCTR.FSK_ALERT where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_ALERT_COMMENT as locking row for access select * from AMLCTR.FSK_ALERT_COMMENT where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_ALERT_DOCUMENT as locking row for access select * from AMLCTR.FSK_ALERT_DOCUMENT where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_ALERT_EMAIL as locking row for access select * from AMLCTR.FSK_ALERT_EMAIL where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_ALERT_ENTITY as locking row for access select * from AMLCTR.FSK_ALERT_ENTITY where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_ALERT_EVENT as locking row for access select * from AMLCTR.FSK_ALERT_EVENT where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_ALERT_REMINDER as locking row for access select * from AMLCTR.FSK_ALERT_REMINDER where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_ALERT_RISK_FACTOR as locking row for access select * from AMLCTR.FSK_ALERT_RISK_FACTOR where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_ASSESSMENT_SEQUENCE as locking row for access select * from AMLCTR.FSK_ASSESSMENT_SEQUENCE where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_CASH_FLOW_ALERT as locking row for access select * from AMLCTR.FSK_CASH_FLOW_ALERT where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_CASH_FLOW_BANK_ALERT as locking row for access select * from AMLCTR.FSK_CASH_FLOW_BANK_ALERT where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_ENTITY_COMMENT as locking row for access select * from AMLCTR.FSK_ENTITY_COMMENT where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_ENTITY_DOCUMENT as locking row for access select * from AMLCTR.FSK_ENTITY_DOCUMENT where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_GROUP as locking row for access select * from AMLCTR.FSK_GROUP where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_GROUP_USER as locking row for access select * from AMLCTR.FSK_GROUP_USER where segment_id = 'BANK1KCTR';

CREATE VIEW BANK1KCTR.FSK_HEADER as select
   HEADER_ID,
   HEADER_NAME,
   HEADER_DESCRIPTION,
   ENTITY_LEVEL_CODE,
   DENORM_TABLE_NAME,
   ALERT_TABLE_NAME,
   HEADER_AUTOGEN_IND,
   HEADER_LOCATION_DESC,
   SOURCE_TYPE_DESC,
   CREATE_USER_ID,
   CREATE_DATE,
   LSTUPDATE_USER_ID,
   LSTUPDATE_DATE,
   HEADER_HOST_DESC,
   LOGICAL_DELETE_IND
   from AMLCTR.FSK_HEADER where segment_id='BANK1KCTR';

CREATE VIEW BANK1KCTR.FSK_HEADER_ELEMENT as select
   HEADER_ID,
   ELEMENT_NAME,
   ELEMENT_TYPE_CODE,
   ELEMENT_LENGTH_COUNT,
   ELEMENT_FORMAT_CODE,
   ELEMENT_LABEL_DESC,
   ELEMENT_USAGE_DESC
   from AMLCTR.FSK_HEADER_ELEMENT where segment_id='BANK1KCTR';

CREATE VIEW BANK1KCTR.FSK_JOB_CALENDAR as locking row for access select * from AMLCTR.FSK_JOB_CALENDAR where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_LIST as locking row for access select * from AMLCTR.FSK_LIST where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_LIST_CATEGORY as locking row for access select * from AMLCTR.FSK_LIST_CATEGORY where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_LIST_ELEMENT as locking row for access select * from AMLCTR.FSK_LIST_ELEMENT where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_LOV as locking row for access select * from AMLCTR.FSK_LOV where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_NETWORK_EXCLUSION as locking row for access select * from AMLCTR.FSK_NETWORK_EXCLUSION where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_PARTY_PROFILE_ALERT as locking row for access select * from AMLCTR.FSK_PARTY_PROFILE_ALERT where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_RISK_ASSESSMENT as locking row for access select * from AMLCTR.FSK_RISK_ASSESSMENT where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_RISK_ASSESSMENT_CLASSIFIER as locking row for access select * from AMLCTR.FSK_RISK_ASSESSMENT_CLASSIFIER where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_RISK_ASSESSMENT_COMMENT as locking row for access select * from AMLCTR.FSK_RISK_ASSESSMENT_COMMENT where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_RISK_ASSESSMENT_DOCUMENT as locking row for access select * from AMLCTR.FSK_RISK_ASSESSMENT_DOCUMENT where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_RISK_ASSESSMENT_EMAIL as locking row for access select * from AMLCTR.FSK_RISK_ASSESSMENT_EMAIL where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_RISK_ASSESSMENT_EVENT as locking row for access select * from AMLCTR.FSK_RISK_ASSESSMENT_EVENT where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_RISK_CLASSIFIER as locking row for access select * from AMLCTR.FSK_RISK_CLASSIFIER where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_RISK_CLASSIFIER_CATEGORY as locking row for access select * from AMLCTR.FSK_RISK_CLASSIFIER_CATEGORY where segment_id = 'BANK1KCTR';

CREATE VIEW BANK1KCTR.FSK_ROUTING_CONSTRAINT as locking row for access select 
	routing_group_id,
	routing_rule_id,
	constraint_sequence_number,
	column_name,
	operator_desc,
	value_desc,
	compound_operator_name
from AMLCTR.FSK_ROUTING_CONSTRAINT where segment_id = 'BANK1KCTR';

CREATE VIEW BANK1KCTR.FSK_ROUTING_GROUP as locking row for access select 
	routing_group_id,
	routing_group_name,
	logical_delete_ind 
from AMLCTR.FSK_ROUTING_GROUP where segment_id = 'BANK1KCTR';

CREATE VIEW BANK1KCTR.FSK_ROUTING_RULE as locking row for access select 
	routing_group_id,
	routing_rule_id,
	route_priority_number,
	route_type_code,
	initial_route_id
from AMLCTR.FSK_ROUTING_RULE where segment_id = 'BANK1KCTR';

CREATE VIEW BANK1KCTR.FSK_SCENARIO as select
   SCENARIO_ID,
   HEADER_ID,
   SCENARIO_NAME,
   SCENARIO_SHORT_DESCRIPTION,
   SCENARIO_DESCRIPTION,
   SCENARIO_CATEGORY_CODE,
   SCENARIO_CODE_LOCATION_DESC,
   PRODUCT_TYPE_CODE,
   SCENARIO_STATUS_CODE,
   SCENARIO_RUN_FREQUENCY_DESC,
   CURRENT_IND,
   INITIAL_ROUTE_ID,
   ROUTE_TYPE_CODE,
   DFLT_SUPPRESS_DURATION_COUNT,
   SCENARIO_DURATION_COUNT,
   MONEY_LAUNDERING_BAYES_WEIGHT,
   TERROR_FINANCING_BAYES_WEIGHT,
   EXECUTION_PROBABILITY_RATE,
   RISK_FACTOR_IND,
   CREATE_DATE,
   CREATE_USER_ID,
   END_DATE,
   END_USER_ID,
   VERSION_NUMBER,
   LOGICAL_DELETE_IND,
   ROUTING_GROUP_ID
   from AMLCTR.FSK_SCENARIO where segment_id='BANK1KCTR';

CREATE VIEW BANK1KCTR.FSK_SCENARIO_PARAMETER as select
   SCENARIO_ID ,
   PARM_NAME ,
   PARM_VALUE ,
   PARM_TYPE_DESC,
   PARM_DESC
   from AMLCTR.FSK_SCENARIO_PARAMETER where segment_id='BANK1KCTR';

CREATE VIEW BANK1KCTR.FSK_SEQUENCE as select
   next_sequence_id
   from AMLCTR.FSK_SEQUENCE where segment_id='BANK1KCTR';
   
CREATE VIEW BANK1KCTR.FSK_TRANSACTION_ALERT as locking row for access select * from AMLCTR.FSK_TRANSACTION_ALERT where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_UI_AVAILABILITY as locking row for access select * from AMLCTR.FSK_UI_AVAILABILITY where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_UI_COLUMN as locking row for access select * from AMLCTR.FSK_UI_COLUMN;
CREATE VIEW BANK1KCTR.FSK_UI_GROUP as locking row for access select * from AMLCTR.FSK_UI_GROUP;
CREATE VIEW BANK1KCTR.FSK_UI_TABLE as locking row for access select * from AMLCTR.FSK_UI_TABLE;
CREATE VIEW BANK1KCTR.FSK_USER as locking row for access select * from AMLCTR.FSK_USER where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_ASSESSMENT_ROUTING_RULE as locking row for access select * from AMLCTR.FSK_ASSESSMENT_ROUTING_RULE where segment_id = 'BANK1KCTR';
CREATE VIEW BANK1KCTR.FSK_ERROR_LOG as locking row for access select * from AMLCTR.FSK_ERROR_LOG;
CREATE VIEW BANK1KCTR.FSK_SCENARIO_STATUS as locking row for access select * from AMLCTR.FSK_SCENARIO_STATUS;

CREATE VIEW BANK2KCTR.FSK_ACCOUNT_EVENT_ALERT as locking row for access select * from AMLCTR.FSK_ACCOUNT_EVENT_ALERT where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_ACCOUNT_PROFILE_ALERT as locking row for access select * from AMLCTR.FSK_ACCOUNT_PROFILE_ALERT where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_ACCOUNT_TRADE_ALERT as locking row for access select * from AMLCTR.FSK_ACCOUNT_TRADE_ALERT where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_ALERT as locking row for access select * from AMLCTR.FSK_ALERT where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_ALERT_COMMENT as locking row for access select * from AMLCTR.FSK_ALERT_COMMENT where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_ALERT_DOCUMENT as locking row for access select * from AMLCTR.FSK_ALERT_DOCUMENT where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_ALERT_EMAIL as locking row for access select * from AMLCTR.FSK_ALERT_EMAIL where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_ALERT_ENTITY as locking row for access select * from AMLCTR.FSK_ALERT_ENTITY where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_ALERT_EVENT as locking row for access select * from AMLCTR.FSK_ALERT_EVENT where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_ALERT_REMINDER as locking row for access select * from AMLCTR.FSK_ALERT_REMINDER where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_ALERT_RISK_FACTOR as locking row for access select * from AMLCTR.FSK_ALERT_RISK_FACTOR where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_ASSESSMENT_SEQUENCE as locking row for access select * from AMLCTR.FSK_ASSESSMENT_SEQUENCE where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_CASH_FLOW_ALERT as locking row for access select * from AMLCTR.FSK_CASH_FLOW_ALERT where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_CASH_FLOW_BANK_ALERT as select * from AMLCTR.FSK_CASH_FLOW_BANK_ALERT where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_ENTITY_COMMENT as select * from AMLCTR.FSK_ENTITY_COMMENT where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_ENTITY_DOCUMENT as select * from AMLCTR.FSK_ENTITY_DOCUMENT where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_GROUP as select * from AMLCTR.FSK_GROUP where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_GROUP_USER as select * from AMLCTR.FSK_GROUP_USER where segment_id = 'BANK2KCTR';

CREATE VIEW BANK2KCTR.FSK_HEADER as select
   HEADER_ID,
   HEADER_NAME,
   HEADER_DESCRIPTION,
   ENTITY_LEVEL_CODE,
   DENORM_TABLE_NAME,
   ALERT_TABLE_NAME,
   HEADER_AUTOGEN_IND,
   HEADER_LOCATION_DESC,
   SOURCE_TYPE_DESC,
   CREATE_USER_ID,
   CREATE_DATE,
   LSTUPDATE_USER_ID,
   LSTUPDATE_DATE,
   HEADER_HOST_DESC,
   LOGICAL_DELETE_IND
   from AMLCTR.FSK_HEADER where segment_id='BANK2KCTR';

CREATE VIEW BANK2KCTR.FSK_HEADER_ELEMENT as select
   HEADER_ID,
   ELEMENT_NAME,
   ELEMENT_TYPE_CODE,
   ELEMENT_LENGTH_COUNT,
   ELEMENT_FORMAT_CODE,
   ELEMENT_LABEL_DESC,
   ELEMENT_USAGE_DESC
   from AMLCTR.FSK_HEADER_ELEMENT where segment_id='BANK2KCTR';

CREATE VIEW BANK2KCTR.FSK_JOB_CALENDAR as select * from AMLCTR.FSK_JOB_CALENDAR where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_LIST as select * from AMLCTR.FSK_LIST where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_LIST_CATEGORY as select * from AMLCTR.FSK_LIST_CATEGORY where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_LIST_ELEMENT as select * from AMLCTR.FSK_LIST_ELEMENT where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_LOV as select * from AMLCTR.FSK_LOV where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_NETWORK_EXCLUSION as select * from AMLCTR.FSK_NETWORK_EXCLUSION where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_PARTY_PROFILE_ALERT as select * from AMLCTR.FSK_PARTY_PROFILE_ALERT where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_RISK_ASSESSMENT as select * from AMLCTR.FSK_RISK_ASSESSMENT where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_RISK_ASSESSMENT_CLASSIFIER as select * from AMLCTR.FSK_RISK_ASSESSMENT_CLASSIFIER where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_RISK_ASSESSMENT_COMMENT as select * from AMLCTR.FSK_RISK_ASSESSMENT_COMMENT where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_RISK_ASSESSMENT_DOCUMENT as select * from AMLCTR.FSK_RISK_ASSESSMENT_DOCUMENT where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_RISK_ASSESSMENT_EMAIL as select * from AMLCTR.FSK_RISK_ASSESSMENT_EMAIL where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_RISK_ASSESSMENT_EVENT as select * from AMLCTR.FSK_RISK_ASSESSMENT_EVENT where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_RISK_CLASSIFIER as select * from AMLCTR.FSK_RISK_CLASSIFIER where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_RISK_CLASSIFIER_CATEGORY as select * from AMLCTR.FSK_RISK_CLASSIFIER_CATEGORY where segment_id = 'BANK2KCTR';

CREATE VIEW BANK2KCTR.FSK_ROUTING_CONSTRAINT as select 
	routing_group_id,
	routing_rule_id,
	constraint_sequence_number,
	column_name,
	operator_desc,
	value_desc,
	compound_operator_name
from AMLCTR.FSK_ROUTING_CONSTRAINT where segment_id = 'BANK2KCTR';

CREATE VIEW BANK2KCTR.FSK_ROUTING_GROUP as select 
	routing_group_id,
	routing_group_name,
	logical_delete_ind 
from AMLCTR.FSK_ROUTING_GROUP where segment_id = 'BANK2KCTR';

CREATE VIEW BANK2KCTR.FSK_ROUTING_RULE as select 
	routing_group_id,
	routing_rule_id,
	route_priority_number,
	route_type_code,
	initial_route_id
from AMLCTR.FSK_ROUTING_RULE where segment_id = 'BANK2KCTR';

CREATE VIEW BANK2KCTR.FSK_ERROR_LOG as select * from AMLCTR.FSK_ERROR_LOG;
CREATE VIEW BANK2KCTR.FSK_SCENARIO_STATUS as select * from AMLCTR.FSK_SCENARIO_STATUS;



CREATE VIEW BANK2KCTR.FSK_SCENARIO as select
   SCENARIO_ID,
   HEADER_ID,
   SCENARIO_NAME,
   SCENARIO_SHORT_DESCRIPTION,
   SCENARIO_DESCRIPTION,
   SCENARIO_CATEGORY_CODE,
   SCENARIO_CODE_LOCATION_DESC,
   PRODUCT_TYPE_CODE,
   SCENARIO_STATUS_CODE,
   SCENARIO_RUN_FREQUENCY_DESC,
   CURRENT_IND,
   INITIAL_ROUTE_ID,
   ROUTE_TYPE_CODE,
   DFLT_SUPPRESS_DURATION_COUNT,
   SCENARIO_DURATION_COUNT,
   MONEY_LAUNDERING_BAYES_WEIGHT,
   TERROR_FINANCING_BAYES_WEIGHT,
   EXECUTION_PROBABILITY_RATE,
   RISK_FACTOR_IND,
   CREATE_DATE,
   CREATE_USER_ID,
   END_DATE,
   END_USER_ID,
   VERSION_NUMBER,
   LOGICAL_DELETE_IND,
   ROUTING_GROUP_ID
   from AMLCTR.FSK_SCENARIO where segment_id='BANK2KCTR';

CREATE VIEW BANK2KCTR.FSK_SCENARIO_PARAMETER as select
   SCENARIO_ID ,
   PARM_NAME ,
   PARM_VALUE ,
   PARM_TYPE_DESC,
   PARM_DESC
   from AMLCTR.FSK_SCENARIO_PARAMETER where segment_id='BANK2KCTR';
   
CREATE VIEW BANK2KCTR.FSK_SEQUENCE as select
   next_sequence_id
   from AMLCTR.FSK_SEQUENCE where segment_id='BANK2KCTR';

CREATE VIEW BANK2KCTR.FSK_TRANSACTION_ALERT as select * from AMLCTR.FSK_TRANSACTION_ALERT where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_UI_AVAILABILITY as select * from AMLCTR.FSK_UI_AVAILABILITY where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_UI_COLUMN as select * from AMLCTR.FSK_UI_COLUMN;
CREATE VIEW BANK2KCTR.FSK_UI_GROUP as select * from AMLCTR.FSK_UI_GROUP;
CREATE VIEW BANK2KCTR.FSK_UI_TABLE as select * from AMLCTR.FSK_UI_TABLE;
CREATE VIEW BANK2KCTR.FSK_USER as select * from AMLCTR.FSK_USER where segment_id = 'BANK2KCTR';
CREATE VIEW BANK2KCTR.FSK_ASSESSMENT_ROUTING_RULE as locking row for access select * from AMLCTR.FSK_ASSESSMENT_ROUTING_RULE where segment_id = 'BANK2KCTR';



CREATE VIEW BANK1KCTR.fsk_account_list_view (
   list_id,
   list_element_value )
AS
locking row for access 
SELECT element.list_id,element.list_element_value
FROM AMLCTR.FSK_LIST list
JOIN AMLCTR.FSK_LIST_ELEMENT element ON list.list_id = element.list_id
WHERE list.validation_type_code = 'ACC'
AND list.logical_delete_ind = 'N'
AND element.logical_delete_ind = 'N'
AND list.segment_id = 'BANK1KCTR'
AND element.segment_id = 'BANK1KCTR';

COMMENT ON VIEW BANK1KCTR.fsk_account_list_view IS 'Risk list elements for lists that have an entity_level_code of ACC and an entity_column of account_number.';


CREATE VIEW BANK1KCTR.fsk_party_list_view (
   list_id,
   list_element_value )
AS
locking row for access 
SELECT element.list_id,element.list_element_value
FROM AMLCTR.FSK_LIST list
JOIN AMLCTR.FSK_LIST_ELEMENT element ON list.list_id = element.list_id
WHERE list.validation_type_code = 'PTY'
AND list.logical_delete_ind = 'N'
AND element.logical_delete_ind = 'N'
AND list.segment_id = 'BANK1KCTR'
AND element.segment_id = 'BANK1KCTR';

COMMENT ON VIEW BANK1KCTR.fsk_party_list_view IS 'Risk list elements for lists that have an entity_level_code of PTY and an entity_column of party_number.';



CREATE VIEW BANK2KCTR.fsk_account_list_view (
   list_id,
   list_element_value )
AS
locking row for access 
SELECT element.list_id,element.list_element_value
FROM AMLCTR.FSK_LIST list
JOIN AMLCTR.FSK_LIST_ELEMENT element ON list.list_id = element.list_id
WHERE list.validation_type_code = 'ACC'
AND list.logical_delete_ind = 'N'
AND element.logical_delete_ind = 'N'
AND list.segment_id = 'BANK2KCTR'
AND element.segment_id = 'BANK2KCTR';

COMMENT ON VIEW BANK2KCTR.fsk_account_list_view IS 'Risk list elements for lists that have an entity_level_code of ACC and an entity_column of account_number.';


CREATE VIEW BANK2KCTR.fsk_party_list_view (
   list_id,
   list_element_value )
AS
locking row for access 
SELECT element.list_id,element.list_element_value
FROM AMLCTR.FSK_LIST list
JOIN AMLCTR.FSK_LIST_ELEMENT element ON list.list_id = element.list_id
WHERE list.validation_type_code = 'PTY'
AND list.logical_delete_ind = 'N'
AND element.logical_delete_ind = 'N'
AND list.segment_id = 'BANK2KCTR'
AND element.segment_id = 'BANK2KCTR';

COMMENT ON VIEW BANK2KCTR.fsk_party_list_view IS 'Risk list elements for lists that have an entity_level_code of PTY and an entity_column of party_number.';


CREATE VIEW BANK1KCTR.fsk_customer_transaction_view (
   transaction_reference_number,
   account_number,
   role_desc,
   date_key,
   currency_amount,
   currency_code,
   transaction_cdi_code,
   transaction_cdi_desc,
   primary_medium_desc,
   secondary_medium_desc,
   mechanism_desc,
   country_code,
   secondary_account_number,
   related_ind,
   third_party_ind,
   remitter_name,
   beneficiary_name,
   branch_name,
   associate_name,
   transaction_description,
   status_desc,
   transaction_key,
   account_key,
   secondary_account_key,
   remitter_ext_party_key,
   beneficiary_ext_party_key,
   branch_key,
   associate_key,
   party_number,
   branch_number,
   associate_number )
as
locking row for access 
SELECT
 c.transaction_reference_number,
 acct.account_number,
 br.role_desc,
 cff.date_key,
 cff.currency_amount,
 curr.currency_code,
 cred_typ.transaction_cdi_code,
 cred_typ.transaction_cdi_desc,
 cred_typ.primary_medium_desc,
 cred_typ.secondary_medium_desc,
 cred_typ.mechanism_desc,
 cty.country_code_3 as country_code,
 secacct.account_number,
 cff.related_ind,
 cff.third_party_ind,
 rextpty.full_name as remitter_name, 
 bextpty.full_name as beneficiary_name, 
 branch.branch_name, 
 ass.associate_first_name||' '||ass.associate_middle_name||' '||ass.associate_last_name as associate_name,
 c.transaction_description,
 stat.status_desc,
 c.transaction_key,
 acct.account_key,
 cff.secondary_account_key,
 cff.remitter_ext_party_key,
 cff.beneficiary_ext_party_key,
 branch.branch_key,
 ass.associate_key,
 pty.party_number as party_number,
 branch.branch_number,
 ass.associate_number
FROM AMLCORE.fsc_cash_flow_fact cff 
JOIN AMLCORE.fsc_account_dim acct on cff.account_key = acct.account_key and cff.segment_id = acct.segment_id
JOIN AMLCORE.fsc_account_dim secacct on cff.secondary_account_key = secacct.account_key and cff.segment_id = secacct.segment_id
JOIN AMLCORE.fsc_transaction_dim c ON cff.transaction_key=c.transaction_key and cff.segment_id = c.segment_id
JOIN AMLCORE.fsc_transaction_type_dim cred_typ ON cred_typ.transaction_type_key = cff.transaction_type_key
JOIN AMLCORE.fsc_party_account_bridge br on br.account_key = cff.account_key and br.segment_id = cff.segment_id
JOIN AMLCORE.fsc_currency_dim curr on curr.currency_key = cff.transaction_currency_key 
JOIN AMLCORE.fsc_country_dim cty on cty.country_key = cff.country_key
JOIN AMLCORE.fsc_branch_dim branch on branch.branch_key = cff.branch_key and cff.segment_id = branch.segment_id
JOIN AMLCORE.fsc_associate_dim ass on ass.associate_key = cff.associate_key and cff.segment_id = ass.segment_id
JOIN AMLCORE.fsc_ext_party_account_dim rextpty on cff.remitter_ext_party_key = rextpty.ext_party_account_key and cff.segment_id = rextpty.segment_id
JOIN AMLCORE.fsc_ext_party_account_dim bextpty on cff.beneficiary_ext_party_key = bextpty.ext_party_account_key and cff.segment_id = bextpty.segment_id
JOIN AMLCORE.fsc_transaction_status_dim stat on cff.transaction_status_key = stat.transaction_status_key
JOIN AMLCORE.fsc_party_dim pty on pty.party_key = br.party_key and pty.segment_id = br.segment_id
WHERE cff.segment_id = 'BANK1KCTR'
UNION 
SELECT 
 c.transaction_reference_number,
 acct.account_number,
 br.role_desc,
 c.date_key,
 trd.principal_amount_in_txn_ccy,
 curr.currency_code,
 cred_typ.transaction_cdi_code,
 cred_typ.transaction_cdi_desc,
 cred_typ.primary_medium_desc,
 cred_typ.secondary_medium_desc,
 cred_typ.mechanism_desc,
 ' ' as country_code,
 ' ' as account_number,
 ' ' as related_ind,
 ' ' as third_party_ind,
 ' ' as remitter_name, 
 ' ' as beneficiary_name, 
 branch.branch_name, 
 ass.associate_first_name||' '||ass.associate_middle_name||' '||ass.associate_last_name as associate_name,
 c.transaction_description,
 stat.status_desc,
 c.transaction_key,
 acct.account_key,
 CAST(NULL as NUMERIC(10)) secondary_account_key,
 CAST(NULL as NUMERIC(10)) remitter_ext_party_key,
 CAST(NULL as NUMERIC(10)) beneficiary_ext_party_key,
 branch.branch_key,
 ass.associate_key,
 pty.party_number as party_number,
 branch.branch_number,
 ass.associate_number
FROM AMLCORE.fsc_account_trade_fact trd 
JOIN AMLCORE.fsc_account_dim acct on trd.account_key = acct.account_key and trd.segment_id = acct.segment_id
JOIN AMLCORE.fsc_transaction_dim c ON trd.transaction_key=c.transaction_key and trd.segment_id = c.segment_id
JOIN AMLCORE.fsc_transaction_type_dim cred_typ ON cred_typ.transaction_type_key = trd.transaction_type_key 
JOIN AMLCORE.fsc_party_account_bridge br on br.account_key = trd.account_key and br.segment_id = trd.segment_id
JOIN AMLCORE.fsc_associate_dim ass on ass.associate_key = trd.associate_key and ass.segment_id = trd.segment_id
JOIN AMLCORE.fsc_currency_dim curr on curr.currency_key = trd.transaction_currency_key
JOIN AMLCORE.fsc_branch_dim branch on branch.branch_key = trd.branch_key and branch.segment_id = trd.segment_id
JOIN AMLCORE.fsc_transaction_status_dim stat on stat.transaction_status_key = trd.transaction_status_key
JOIN AMLCORE.fsc_party_dim pty on pty.party_key = br.party_key and pty.segment_id = br.segment_id
WHERE trd.segment_id = 'BANK1KCTR'
UNION 
SELECT
 c.transaction_reference_number,
 acct.account_number,
 br.role_desc,
 c.date_key,
 0 as principal_amount_in_txn_ccy,
 ' ' as currency_code,
 cred_typ.transaction_cdi_code,
 cred_typ.transaction_cdi_desc,
 cred_typ.primary_medium_desc,
 cred_typ.secondary_medium_desc,
 cred_typ.mechanism_desc,
 ' ' as country_code,
 ' ' as account_number,
 ' ' as related_ind,
 ' ' as third_party_ind,
 ' ' as remitter_name, 
 ' ' as beneficiary_name, 
 branch.branch_name, 
 ' ' as associate_name,
 c.transaction_description,
 stat.status_desc,
 c.transaction_key,
 acct.account_key,
 CAST(NULL as NUMERIC(10)) secondary_account_key,
 CAST(NULL as NUMERIC(10)) remitter_ext_party_key,
 CAST(NULL as NUMERIC(10)) beneficiary_ext_party_key,
 branch.branch_key,
 CAST(NULL as NUMERIC(10)) associate_key,
 pty.party_number as party_number,
 branch.branch_number,
 CAST(NULL as CHAR(1)) associate_number
FROM AMLCORE.fsc_account_event_fact evt 
JOIN AMLCORE.fsc_account_dim acct on evt.account_key = acct.account_key and evt.segment_id = acct.segment_id
JOIN AMLCORE.fsc_transaction_dim c ON evt.transaction_key=c.transaction_key and evt.segment_id = c.segment_id
JOIN AMLCORE.fsc_transaction_type_dim cred_typ ON cred_typ.transaction_type_key = evt.transaction_type_key 
JOIN AMLCORE.fsc_party_account_bridge br on br.account_key = evt.account_key and br.segment_id = evt.segment_id
JOIN AMLCORE.fsc_branch_dim branch on branch.branch_key = evt.branch_key and branch.segment_id = evt.segment_id
JOIN AMLCORE.fsc_transaction_status_dim stat on evt.transaction_status_key = stat.transaction_status_key 
JOIN AMLCORE.fsc_party_dim pty on pty.party_key = br.party_key and pty.segment_id = br.segment_id
WHERE evt.segment_id = 'BANK1KCTR'
UNION
SELECT
 fta.transaction_reference_number,
 acct.account_number,
 br.role_desc,
 cfa.date_key,
 cfa.currency_amount,
 curr.currency_code,
 cred_typ.transaction_cdi_code,
 cred_typ.transaction_cdi_desc,
 cred_typ.primary_medium_desc,
 cred_typ.secondary_medium_desc,
 cred_typ.mechanism_desc,
 cty.country_code_3 as country_code,
 secacct.account_number,
 cfa.related_ind,
 cfa.third_party_ind,
 rextpty.full_name as remitter_name, 
 bextpty.full_name as beneficiary_name, 
 branch.branch_name, 
 ass.associate_first_name||' '||ass.associate_middle_name||' '||ass.associate_last_name as associate_name,
 fta.transaction_description,
 stat.status_desc,
 fta.transaction_key,
 acct.account_key,
 cfa.secondary_account_key,
 cfa.remitter_ext_party_key,
 cfa.beneficiary_ext_party_key,
 branch.branch_key,
 ass.associate_key,
 pty.party_number as party_number,
 branch.branch_number,
 ass.associate_number
FROM AMLCTR.fsk_cash_flow_alert cfa 
JOIN AMLCORE.fsc_account_dim acct on cfa.account_key = acct.account_key and cfa.segment_id = acct.segment_id
JOIN AMLCORE.fsc_account_dim secacct on cfa.secondary_account_key = secacct.account_key and cfa.segment_id = secacct.segment_id
JOIN AMLCTR.fsk_transaction_alert fta ON cfa.transaction_key=fta.transaction_key and cfa.segment_id = fta.segment_id
JOIN AMLCORE.fsc_transaction_type_dim cred_typ ON cred_typ.transaction_type_key = cfa.transaction_type_key 
JOIN AMLCORE.fsc_party_account_bridge br on br.account_key = cfa.account_key and br.segment_id = cfa.segment_id
JOIN AMLCORE.fsc_currency_dim curr on curr.currency_key = cfa.transaction_currency_key
JOIN AMLCORE.fsc_country_dim cty on cty.country_key = cfa.country_key 
JOIN AMLCORE.fsc_branch_dim branch on branch.branch_key = cfa.branch_key and branch.segment_id = cfa.segment_id
JOIN AMLCORE.fsc_associate_dim ass on ass.associate_key = cfa.associate_key and ass.segment_id = cfa.segment_id
JOIN AMLCORE.fsc_ext_party_account_dim rextpty on cfa.remitter_ext_party_key = rextpty.ext_party_account_key and cfa.segment_id = rextpty.segment_id
JOIN AMLCORE.fsc_ext_party_account_dim bextpty on cfa.beneficiary_ext_party_key = bextpty.ext_party_account_key and cfa.segment_id = bextpty.segment_id
JOIN AMLCORE.fsc_transaction_status_dim stat on cfa.transaction_status_key = stat.transaction_status_key
JOIN AMLCORE.fsc_party_dim pty on pty.party_key = br.party_key and pty.segment_id = br.segment_id
WHERE cfa.segment_id = 'BANK1KCTR'
UNION 
SELECT 
 fta.transaction_reference_number,
 acct.account_number,
 br.role_desc,
 fta.date_key,
 trdalrt.principal_amount_in_txn_ccy,
 curr.currency_code,
 cred_typ.transaction_cdi_code,
 cred_typ.transaction_cdi_desc,
 cred_typ.primary_medium_desc,
 cred_typ.secondary_medium_desc,
 cred_typ.mechanism_desc,
 ' ' as country_code,
 ' ' as account_number,
 ' ' as related_ind,
 ' ' as third_party_ind,
 ' ' as remitter_name, 
 ' ' as beneficiary_name, 
 branch.branch_name, 
 ass.associate_first_name||' '||ass.associate_middle_name||' '||ass.associate_last_name as associate_name,
 fta.transaction_description,
 stat.status_desc,
 fta.transaction_key,
 acct.account_key,
 CAST(NULL as NUMERIC(10)) secondary_account_key,
 CAST(NULL as NUMERIC(10)) remitter_ext_party_key,
 CAST(NULL as NUMERIC(10)) beneficiary_ext_party_key,
 branch.branch_key,
 ass.associate_key,
 pty.party_number as party_number,
 branch.branch_number,
 ass.associate_number
FROM AMLCTR.fsk_account_trade_alert trdalrt 
JOIN AMLCORE.fsc_account_dim acct on trdalrt.account_key = acct.account_key and trdalrt.segment_id = acct.segment_id
JOIN AMLCTR.fsk_transaction_alert fta ON trdalrt.transaction_key=fta.transaction_key and trdalrt.segment_id = fta.segment_id
JOIN AMLCORE.fsc_transaction_type_dim cred_typ ON cred_typ.transaction_type_key = trdalrt.transaction_type_key 
JOIN AMLCORE.fsc_party_account_bridge br on br.account_key = trdalrt.account_key and br.segment_id = trdalrt.segment_id
JOIN AMLCORE.fsc_associate_dim ass on ass.associate_key = trdalrt.associate_key and ass.segment_id = trdalrt.segment_id
JOIN AMLCORE.fsc_currency_dim curr on curr.currency_key = trdalrt.transaction_currency_key
JOIN AMLCORE.fsc_branch_dim branch on branch.branch_key = trdalrt.branch_key and branch.segment_id = trdalrt.segment_id
JOIN AMLCORE.fsc_transaction_status_dim stat on trdalrt.transaction_status_key = stat.transaction_status_key
JOIN AMLCORE.fsc_party_dim pty on pty.party_key = br.party_key and pty.segment_id = br.segment_id
WHERE trdalrt.segment_id = 'BANK1KCTR'
UNION 
SELECT
 fta.transaction_reference_number,
 acct.account_number,
 br.role_desc,
 fta.date_key,
 0 as principal_amount_in_txn_ccy,
 ' ' as currency_code,
 cred_typ.transaction_cdi_code,
 cred_typ.transaction_cdi_desc,
 cred_typ.primary_medium_desc,
 cred_typ.secondary_medium_desc,
 cred_typ.mechanism_desc,
 ' ' as country_code,
 ' ' as account_number,
 ' ' as related_ind,
 ' ' as third_party_ind,
 ' ' as remitter_name, 
 ' ' as beneficiary_name, 
 branch.branch_name, 
 ' ' as associate_name,
 fta.transaction_description,
 stat.status_desc,
 fta.transaction_key,
 acct.account_key,
 CAST(NULL as NUMERIC(10)) secondary_account_key,
 CAST(NULL as NUMERIC(10)) remitter_ext_party_key,
 CAST(NULL as NUMERIC(10)) beneficiary_ext_party_key,
 branch.branch_key,
 CAST(NULL as NUMERIC(10)) associate_key,
 pty.party_number as party_number,
 branch.branch_number,
 CAST(NULL as CHAR(1)) associate_number
FROM AMLCTR.fsk_account_event_alert evtalrt 
JOIN AMLCORE.fsc_account_dim acct on evtalrt.account_key = acct.account_key and evtalrt.segment_id = acct.segment_id
JOIN AMLCTR.fsk_transaction_alert fta ON evtalrt.transaction_key=fta.transaction_key and evtalrt.segment_id = fta.segment_id
JOIN AMLCORE.fsc_transaction_type_dim cred_typ ON cred_typ.transaction_type_key = evtalrt.transaction_type_key 
JOIN AMLCORE.fsc_party_account_bridge br on br.account_key = evtalrt.account_key and br.segment_id = evtalrt.segment_id
JOIN AMLCORE.fsc_branch_dim branch on branch.branch_key = evtalrt.branch_key and branch.segment_id = evtalrt.segment_id
JOIN AMLCORE.fsc_transaction_status_dim stat on evtalrt.transaction_status_key = stat.transaction_status_key 
JOIN AMLCORE.fsc_party_dim pty on pty.party_key = br.party_key and pty.segment_id = br.segment_id
WHERE evtalrt.segment_id = 'BANK1KCTR'
;



CREATE VIEW BANK2KCTR.fsk_customer_transaction_view (
   transaction_reference_number,
   account_number,
   role_desc,
   date_key,
   currency_amount,
   currency_code,
   transaction_cdi_code,
   transaction_cdi_desc,
   primary_medium_desc,
   secondary_medium_desc,
   mechanism_desc,
   country_code,
   secondary_account_number,
   related_ind,
   third_party_ind,
   remitter_name,
   beneficiary_name,
   branch_name,
   associate_name,
   transaction_description,
   status_desc,
   transaction_key,
   account_key,
   secondary_account_key,
   remitter_ext_party_key,
   beneficiary_ext_party_key,
   branch_key,
   associate_key,
   party_number,
   branch_number,
   associate_number )
as
locking row for access 
SELECT
 c.transaction_reference_number,
 acct.account_number,
 br.role_desc,
 cff.date_key,
 cff.currency_amount,
 curr.currency_code,
 cred_typ.transaction_cdi_code,
 cred_typ.transaction_cdi_desc,
 cred_typ.primary_medium_desc,
 cred_typ.secondary_medium_desc,
 cred_typ.mechanism_desc,
 cty.country_code_3 as country_code,
 secacct.account_number,
 cff.related_ind,
 cff.third_party_ind,
 rextpty.full_name as remitter_name, 
 bextpty.full_name as beneficiary_name, 
 branch.branch_name, 
 ass.associate_first_name||' '||ass.associate_middle_name||' '||ass.associate_last_name as associate_name,
 c.transaction_description,
 stat.status_desc,
 c.transaction_key,
 acct.account_key,
 cff.secondary_account_key,
 cff.remitter_ext_party_key,
 cff.beneficiary_ext_party_key,
 branch.branch_key,
 ass.associate_key,
 pty.party_number as party_number,
 branch.branch_number,
 ass.associate_number
FROM AMLCORE.fsc_cash_flow_fact cff 
JOIN AMLCORE.fsc_account_dim acct on cff.account_key = acct.account_key and cff.segment_id = acct.segment_id
JOIN AMLCORE.fsc_account_dim secacct on cff.secondary_account_key = secacct.account_key and cff.segment_id = secacct.segment_id
JOIN AMLCORE.fsc_transaction_dim c ON cff.transaction_key=c.transaction_key and cff.segment_id = c.segment_id
JOIN AMLCORE.fsc_transaction_type_dim cred_typ ON cred_typ.transaction_type_key = cff.transaction_type_key
JOIN AMLCORE.fsc_party_account_bridge br on br.account_key = cff.account_key and br.segment_id = cff.segment_id
JOIN AMLCORE.fsc_currency_dim curr on curr.currency_key = cff.transaction_currency_key 
JOIN AMLCORE.fsc_country_dim cty on cty.country_key = cff.country_key
JOIN AMLCORE.fsc_branch_dim branch on branch.branch_key = cff.branch_key and cff.segment_id = branch.segment_id
JOIN AMLCORE.fsc_associate_dim ass on ass.associate_key = cff.associate_key and cff.segment_id = ass.segment_id
JOIN AMLCORE.fsc_ext_party_account_dim rextpty on cff.remitter_ext_party_key = rextpty.ext_party_account_key and cff.segment_id = rextpty.segment_id
JOIN AMLCORE.fsc_ext_party_account_dim bextpty on cff.beneficiary_ext_party_key = bextpty.ext_party_account_key and cff.segment_id = bextpty.segment_id
JOIN AMLCORE.fsc_transaction_status_dim stat on cff.transaction_status_key = stat.transaction_status_key
JOIN AMLCORE.fsc_party_dim pty on pty.party_key = br.party_key and pty.segment_id = br.segment_id
WHERE cff.segment_id = 'BANK2KCTR'
UNION 
SELECT 
 c.transaction_reference_number,
 acct.account_number,
 br.role_desc,
 c.date_key,
 trd.principal_amount_in_txn_ccy,
 curr.currency_code,
 cred_typ.transaction_cdi_code,
 cred_typ.transaction_cdi_desc,
 cred_typ.primary_medium_desc,
 cred_typ.secondary_medium_desc,
 cred_typ.mechanism_desc,
 ' ' as country_code,
 ' ' as account_number,
 ' ' as related_ind,
 ' ' as third_party_ind,
 ' ' as remitter_name, 
 ' ' as beneficiary_name, 
 branch.branch_name, 
 ass.associate_first_name||' '||ass.associate_middle_name||' '||ass.associate_last_name as associate_name,
 c.transaction_description,
 stat.status_desc,
 c.transaction_key,
 acct.account_key,
 CAST(NULL as NUMERIC(10)) secondary_account_key,
 CAST(NULL as NUMERIC(10)) remitter_ext_party_key,
 CAST(NULL as NUMERIC(10)) beneficiary_ext_party_key,
 branch.branch_key,
 ass.associate_key,
 pty.party_number as party_number,
 branch.branch_number,
 ass.associate_number
FROM AMLCORE.fsc_account_trade_fact trd 
JOIN AMLCORE.fsc_account_dim acct on trd.account_key = acct.account_key and trd.segment_id = acct.segment_id
JOIN AMLCORE.fsc_transaction_dim c ON trd.transaction_key=c.transaction_key and trd.segment_id = c.segment_id
JOIN AMLCORE.fsc_transaction_type_dim cred_typ ON cred_typ.transaction_type_key = trd.transaction_type_key 
JOIN AMLCORE.fsc_party_account_bridge br on br.account_key = trd.account_key and br.segment_id = trd.segment_id
JOIN AMLCORE.fsc_associate_dim ass on ass.associate_key = trd.associate_key and ass.segment_id = trd.segment_id
JOIN AMLCORE.fsc_currency_dim curr on curr.currency_key = trd.transaction_currency_key
JOIN AMLCORE.fsc_branch_dim branch on branch.branch_key = trd.branch_key and branch.segment_id = trd.segment_id
JOIN AMLCORE.fsc_transaction_status_dim stat on stat.transaction_status_key = trd.transaction_status_key
JOIN AMLCORE.fsc_party_dim pty on pty.party_key = br.party_key and pty.segment_id = br.segment_id
WHERE trd.segment_id = 'BANK2KCTR'
UNION 
SELECT
 c.transaction_reference_number,
 acct.account_number,
 br.role_desc,
 c.date_key,
 0 as principal_amount_in_txn_ccy,
 ' ' as currency_code,
 cred_typ.transaction_cdi_code,
 cred_typ.transaction_cdi_desc,
 cred_typ.primary_medium_desc,
 cred_typ.secondary_medium_desc,
 cred_typ.mechanism_desc,
 ' ' as country_code,
 ' ' as account_number,
 ' ' as related_ind,
 ' ' as third_party_ind,
 ' ' as remitter_name, 
 ' ' as beneficiary_name, 
 branch.branch_name, 
 ' ' as associate_name,
 c.transaction_description,
 stat.status_desc,
 c.transaction_key,
 acct.account_key,
 CAST(NULL as NUMERIC(10)) secondary_account_key,
 CAST(NULL as NUMERIC(10)) remitter_ext_party_key,
 CAST(NULL as NUMERIC(10)) beneficiary_ext_party_key,
 branch.branch_key,
 CAST(NULL as NUMERIC(10)) associate_key,
 pty.party_number as party_number,
 branch.branch_number,
 CAST(NULL as CHAR(1)) associate_number
FROM AMLCORE.fsc_account_event_fact evt 
JOIN AMLCORE.fsc_account_dim acct on evt.account_key = acct.account_key and evt.segment_id = acct.segment_id
JOIN AMLCORE.fsc_transaction_dim c ON evt.transaction_key=c.transaction_key and evt.segment_id = c.segment_id
JOIN AMLCORE.fsc_transaction_type_dim cred_typ ON cred_typ.transaction_type_key = evt.transaction_type_key 
JOIN AMLCORE.fsc_party_account_bridge br on br.account_key = evt.account_key and br.segment_id = evt.segment_id
JOIN AMLCORE.fsc_branch_dim branch on branch.branch_key = evt.branch_key and branch.segment_id = evt.segment_id
JOIN AMLCORE.fsc_transaction_status_dim stat on evt.transaction_status_key = stat.transaction_status_key 
JOIN AMLCORE.fsc_party_dim pty on pty.party_key = br.party_key and pty.segment_id = br.segment_id
WHERE evt.segment_id = 'BANK2KCTR'
UNION
SELECT
 fta.transaction_reference_number,
 acct.account_number,
 br.role_desc,
 cfa.date_key,
 cfa.currency_amount,
 curr.currency_code,
 cred_typ.transaction_cdi_code,
 cred_typ.transaction_cdi_desc,
 cred_typ.primary_medium_desc,
 cred_typ.secondary_medium_desc,
 cred_typ.mechanism_desc,
 cty.country_code_3 as country_code,
 secacct.account_number,
 cfa.related_ind,
 cfa.third_party_ind,
 rextpty.full_name as remitter_name, 
 bextpty.full_name as beneficiary_name, 
 branch.branch_name, 
 ass.associate_first_name||' '||ass.associate_middle_name||' '||ass.associate_last_name as associate_name,
 fta.transaction_description,
 stat.status_desc,
 fta.transaction_key,
 acct.account_key,
 cfa.secondary_account_key,
 cfa.remitter_ext_party_key,
 cfa.beneficiary_ext_party_key,
 branch.branch_key,
 ass.associate_key,
 pty.party_number as party_number,
 branch.branch_number,
 ass.associate_number
FROM AMLCTR.fsk_cash_flow_alert cfa 
JOIN AMLCORE.fsc_account_dim acct on cfa.account_key = acct.account_key and cfa.segment_id = acct.segment_id
JOIN AMLCORE.fsc_account_dim secacct on cfa.secondary_account_key = secacct.account_key and cfa.segment_id = secacct.segment_id
JOIN AMLCTR.fsk_transaction_alert fta ON cfa.transaction_key=fta.transaction_key and cfa.segment_id = fta.segment_id
JOIN AMLCORE.fsc_transaction_type_dim cred_typ ON cred_typ.transaction_type_key = cfa.transaction_type_key 
JOIN AMLCORE.fsc_party_account_bridge br on br.account_key = cfa.account_key and br.segment_id = cfa.segment_id
JOIN AMLCORE.fsc_currency_dim curr on curr.currency_key = cfa.transaction_currency_key
JOIN AMLCORE.fsc_country_dim cty on cty.country_key = cfa.country_key 
JOIN AMLCORE.fsc_branch_dim branch on branch.branch_key = cfa.branch_key and branch.segment_id = cfa.segment_id
JOIN AMLCORE.fsc_associate_dim ass on ass.associate_key = cfa.associate_key and ass.segment_id = cfa.segment_id
JOIN AMLCORE.fsc_ext_party_account_dim rextpty on cfa.remitter_ext_party_key = rextpty.ext_party_account_key and cfa.segment_id = rextpty.segment_id
JOIN AMLCORE.fsc_ext_party_account_dim bextpty on cfa.beneficiary_ext_party_key = bextpty.ext_party_account_key and cfa.segment_id = bextpty.segment_id
JOIN AMLCORE.fsc_transaction_status_dim stat on cfa.transaction_status_key = stat.transaction_status_key
JOIN AMLCORE.fsc_party_dim pty on pty.party_key = br.party_key and pty.segment_id = br.segment_id
WHERE cfa.segment_id = 'BANK2KCTR'
UNION 
SELECT 
 fta.transaction_reference_number,
 acct.account_number,
 br.role_desc,
 fta.date_key,
 trdalrt.principal_amount_in_txn_ccy,
 curr.currency_code,
 cred_typ.transaction_cdi_code,
 cred_typ.transaction_cdi_desc,
 cred_typ.primary_medium_desc,
 cred_typ.secondary_medium_desc,
 cred_typ.mechanism_desc,
 ' ' as country_code,
 ' ' as account_number,
 ' ' as related_ind,
 ' ' as third_party_ind,
 ' ' as remitter_name, 
 ' ' as beneficiary_name, 
 branch.branch_name, 
 ass.associate_first_name||' '||ass.associate_middle_name||' '||ass.associate_last_name as associate_name,
 fta.transaction_description,
 stat.status_desc,
 fta.transaction_key,
 acct.account_key,
 CAST(NULL as NUMERIC(10)) secondary_account_key,
 CAST(NULL as NUMERIC(10)) remitter_ext_party_key,
 CAST(NULL as NUMERIC(10)) beneficiary_ext_party_key,
 branch.branch_key,
 ass.associate_key,
 pty.party_number as party_number,
 branch.branch_number,
 ass.associate_number
FROM AMLCTR.fsk_account_trade_alert trdalrt 
JOIN AMLCORE.fsc_account_dim acct on trdalrt.account_key = acct.account_key and trdalrt.segment_id = acct.segment_id
JOIN AMLCTR.fsk_transaction_alert fta ON trdalrt.transaction_key=fta.transaction_key and trdalrt.segment_id = fta.segment_id
JOIN AMLCORE.fsc_transaction_type_dim cred_typ ON cred_typ.transaction_type_key = trdalrt.transaction_type_key 
JOIN AMLCORE.fsc_party_account_bridge br on br.account_key = trdalrt.account_key and br.segment_id = trdalrt.segment_id
JOIN AMLCORE.fsc_associate_dim ass on ass.associate_key = trdalrt.associate_key and ass.segment_id = trdalrt.segment_id
JOIN AMLCORE.fsc_currency_dim curr on curr.currency_key = trdalrt.transaction_currency_key
JOIN AMLCORE.fsc_branch_dim branch on branch.branch_key = trdalrt.branch_key and branch.segment_id = trdalrt.segment_id
JOIN AMLCORE.fsc_transaction_status_dim stat on trdalrt.transaction_status_key = stat.transaction_status_key
JOIN AMLCORE.fsc_party_dim pty on pty.party_key = br.party_key and pty.segment_id = br.segment_id
WHERE trdalrt.segment_id = 'BANK2KCTR'
UNION 
SELECT
 fta.transaction_reference_number,
 acct.account_number,
 br.role_desc,
 fta.date_key,
 0 as principal_amount_in_txn_ccy,
 ' ' as currency_code,
 cred_typ.transaction_cdi_code,
 cred_typ.transaction_cdi_desc,
 cred_typ.primary_medium_desc,
 cred_typ.secondary_medium_desc,
 cred_typ.mechanism_desc,
 ' ' as country_code,
 ' ' as account_number,
 ' ' as related_ind,
 ' ' as third_party_ind,
 ' ' as remitter_name, 
 ' ' as beneficiary_name, 
 branch.branch_name, 
 ' ' as associate_name,
 fta.transaction_description,
 stat.status_desc,
 fta.transaction_key,
 acct.account_key,
 CAST(NULL as NUMERIC(10)) secondary_account_key,
 CAST(NULL as NUMERIC(10)) remitter_ext_party_key,
 CAST(NULL as NUMERIC(10)) beneficiary_ext_party_key,
 branch.branch_key,
 CAST(NULL as NUMERIC(10)) associate_key,
 pty.party_number as party_number,
 branch.branch_number,
 CAST(NULL as CHAR(1)) associate_number
FROM AMLCTR.fsk_account_event_alert evtalrt 
JOIN AMLCORE.fsc_account_dim acct on evtalrt.account_key = acct.account_key and evtalrt.segment_id = acct.segment_id
JOIN AMLCTR.fsk_transaction_alert fta ON evtalrt.transaction_key=fta.transaction_key and evtalrt.segment_id = fta.segment_id
JOIN AMLCORE.fsc_transaction_type_dim cred_typ ON cred_typ.transaction_type_key = evtalrt.transaction_type_key 
JOIN AMLCORE.fsc_party_account_bridge br on br.account_key = evtalrt.account_key and br.segment_id = evtalrt.segment_id
JOIN AMLCORE.fsc_branch_dim branch on branch.branch_key = evtalrt.branch_key and branch.segment_id = evtalrt.segment_id
JOIN AMLCORE.fsc_transaction_status_dim stat on evtalrt.transaction_status_key = stat.transaction_status_key 
JOIN AMLCORE.fsc_party_dim pty on pty.party_key = br.party_key and pty.segment_id = br.segment_id
WHERE evtalrt.segment_id = 'BANK2KCTR';

----------------------------------------------------------------------------
--Create sequences in each multibank segment schema. Additional sequences 
--will be needed if this script is customized to add additional multibank segments.
----------------------------------------------------------------------------
create table BANK1KCTR.FSK_SEQ (next_sequence_id NUMERIC(10));
bt;
insert into BANK1KCTR.FSK_SEQ (next_sequence_id) values (11000);
et;

create table BANK2KCTR.FSK_SEQ (next_sequence_id NUMERIC(10));
bt;
insert into BANK2KCTR.FSK_SEQ (next_sequence_id) values (11000);
et;

REPLACE PROCEDURE bank1kctr.GET_SEQ(OUT NEXT_SEQ DECIMAL(10,0))
BEGIN
BT;
select next_sequence_id from bank1kctr.fsk_seq into next_seq;
update bank1kctr.fsk_seq
set next_sequence_id = next_sequence_id + 1;
ET;
END;
et;
REPLACE PROCEDURE bank2kctr.GET_SEQ(OUT NEXT_SEQ DECIMAL(10,0))
BEGIN
BT;
select next_sequence_id from bank2kctr.fsk_seq into next_seq;
update bank2kctr.fsk_seq
set next_sequence_id = next_sequence_id + 1;
ET;
END;

/*
--The following views are used by Teradata Scenario code only. They are not referenced by the UI.
*/


REPLACE VIEW BANK1KCTR.AccountProfileView
-- ------------+--------------------------------------------------------
-- Copyright (c) 2006 by SAS Institute Inc., Cary, NC 27513 USA
-- All Rights Reserved
-- ------------+--------------------------------------------------------
-- Product
--             | SAS Anti-Money Laundering
--             | Anti-Money Laundering Prep View
-- Description
--             | Prep data views containing the data required to execute
--             | scenarios AND risk factors.
-- ------------+--------------------------------------------------------
(account_Number
,account_type_desc
,avg_Account_Value_Amount
,cust_Initiated_Trans_Count
,max_Account_Value_Amount
,min_Account_Value_Amount
,month_key
,total_Credits_Amount
,total_Debits_Amount
,total_Wire_Credits_Amount
,total_Wire_Debits_Amount
,wires_Count)
AS
locking row for access 
SELECT
a.account_number
,b.account_type_desc
,a.avg_Account_Value_Amount
,a.cust_Initiated_Trans_Count
,a.max_Account_Value_Amount
,a.min_Account_Value_Amount
,a. month_key
,a.total_Credits_Amount
,a.total_Debits_Amount
,a.total_Wire_Credits_Amount
,a.total_Wire_Debits_Amount
,a.wires_Count
FROM AMLCORE.fsc_account_profile_fact a
	,AMLCORE.fsc_account_dim b
WHERE a.account_number=b.account_number
		AND a.segment_id = b.segment_id
		AND a.segment_id = 'BANK1KCTR'
		AND b.change_current_ind='Y';

REPLACE VIEW BANK1KCTR.AccountTransactionView
-- ------------+--------------------------------------------------------
-- Copyright (c) 2006 by SAS Institute Inc., Cary, NC 27513 USA
-- All Rights Reserved
-- ------------+--------------------------------------------------------
-- Product
--             | SAS Anti-Money Laundering
--             | Anti-Money Laundering Prep View
-- Description
--             | Prep data views containing the data required to execute
--             | scenarios AND risk factors.
-- ------------+--------------------------------------------------------
(
account_number
,account_tax_state_code
,account_type_desc
,annual_income_amount
,branch_number
,branch_type_desc
,currency_amount
,currency_based_account_ind
,currency_code
,customer_since_date
,date_key
,expected_credit_ceiling_amount
,expected_debit_ceiling_amount
,expected_incoming_amount
,expected_incoming_count
,expected_outgoing_amount
,expected_outgoing_count
,increased_behavior_credit_amt
,increased_behavior_credit_cnt
,increased_behavior_debit_amt
,increased_behavior_debit_cnt
,last_cash_trans_rpt_date
,last_susp_actv_rpt_date
,mechanism_desc
,politically_exposed_person_ind
,primary_medium_desc
,secondary_medium_desc
,status_desc
,status_reason_desc
,street_state_code
,transaction_cdi_code
,transaction_key

) AS
locking row for access 
SELECT
aa.account_number
,aa.account_tax_state_code
,aa.account_type_desc
,aa.annual_income_amount
,aa.branch_number
,aa.branch_type_desc
,aa.currency_amount
,aa.currency_based_account_ind
,aa.currency_code
,aa.customer_since_date
,aa.date_key
,x.expected_credit_ceiling_amount
,x.expected_debit_ceiling_amount
,x.expected_incoming_amount
,x.expected_incoming_count
,x.expected_outgoing_amount
,x.expected_outgoing_count
,x.increased_behavior_credit_amt
,x.increased_behavior_credit_cnt
,x.increased_behavior_debit_amt
,x.increased_behavior_debit_cnt
,aa.last_cash_trans_rpt_date
,aa.last_susp_actv_rpt_date
,aa.mechanism_desc
,aa.politically_exposed_person_ind
,aa.primary_medium_desc
,aa.secondary_medium_desc
,aa.status_desc
,aa.status_reason_desc
,aa.street_state_code
,aa.transaction_cdi_code
,aa.transaction_key

FROM
(SELECT
 A.account_number
, A.segment_id
, A.account_tax_state_code
, A.account_type_desc
, B.annual_income_amount
, D.branch_number
, D.branch_type_desc
, I.currency_amount
, A.currency_based_account_ind
, F.currency_code
, B.customer_since_date
, I.date_key
, b.last_cash_trans_rpt_date
, b.last_susp_actv_rpt_date
, c.mechanism_desc
, b.politically_exposed_person_ind
, c.primary_medium_desc
, c.secondary_medium_desc
, g.status_desc
, g.status_reason_desc
, d.street_state_code
, c.transaction_cdi_code
, i.transaction_key
FROM
 AMLCORE.fsc_account_dim A
,AMLCORE.fsc_party_dim B
,AMLCORE.fsc_transaction_type_dim C
,AMLCORE.fsc_branch_dim D
,AMLCORE.fsc_country_dim E
,AMLCORE.fsc_currency_dim F
,AMLCORE.fsc_transaction_status_dim G
,AMLCORE.fsc_party_account_bridge H
,AMLCORE.fsc_cash_flow_fact I
WHERE
 I.account_key = A.account_key
 AND I.segment_id = A.segment_id
 AND A.account_key = H.account_key
 AND A.segment_id = H.segment_id
 AND B.party_key = H.party_key
 AND B.segment_id = H.segment_id
 AND I.transaction_type_key = C.transaction_type_key
 AND I.transaction_status_key = G.transaction_status_key
 AND I.country_key = E.country_key
 AND I.branch_key = D.branch_key
 AND I.segment_id = D.segment_id
 AND I.transaction_currency_key = F.currency_key
 AND H.role_desc = 'PRIMARY OWNER'
 AND H.change_current_ind = 'Y'
 AND A.segment_id = 'BANK1KCTR'
UNION ALL
SELECT
 A.account_number
 ,A.segment_id
 ,A.account_tax_state_code
 ,A.account_type_desc
 ,B.annual_income_amount
 ,D.branch_number
 ,D.branch_type_desc
 ,0 as currency_amount
 ,A.currency_based_account_ind
 ,'' as currency_code
 ,B.customer_since_date
 ,I.date_key
 ,B.last_cash_trans_rpt_date
 ,B.last_susp_actv_rpt_date
 ,C.mechanism_desc
 ,B.politically_exposed_person_ind
 ,C.primary_medium_desc
 ,C.secondary_medium_desc
 ,D.street_state_code
 ,G.status_desc
 ,G.status_reason_desc
 ,C.transaction_cdi_code
 ,I.transaction_key
FROM
AMLCORE.fsc_account_dim A
,AMLCORE.fsc_party_dim B
,AMLCORE.fsc_transaction_type_dim C
,AMLCORE.fsc_branch_dim D
,AMLCORE.fsc_country_dim E
,AMLCORE.fsc_transaction_status_dim G
,AMLCORE.fsc_party_account_bridge H
,AMLCORE.fsc_account_event_fact I
WHERE
 I.account_key = A.account_key
 AND I.segment_id = A.segment_id
 AND A.account_key = H.account_key
 AND A.segment_id = H.segment_id
 AND B.party_key = H.party_key
 AND B.segment_id = H.segment_id
 AND I.transaction_type_key = C.transaction_type_key
 AND I.transaction_status_key = G.transaction_status_key
 AND I.country_key = E.country_key
 AND I.branch_key = D.branch_key
 AND I.segment_id = D.segment_id
 AND H.role_desc = 'PRIMARY OWNER'
 AND H.change_current_ind = 'Y'
 AND A.segment_id = 'BANK1KCTR'
)aa
LEFT JOIN
AMLCORE.fsc_account_analysis_dim x
ON
aa.account_number=x.account_number
AND aa.segment_id = x.segment_id
and x.segment_id = 'BANK1KCTR';

REPLACE VIEW BANK1KCTR.DormantAccountTransactionView
-- ------------+--------------------------------------------------------
-- Copyright (c) 2006 by SAS Institute Inc., Cary, NC 27513 USA
-- All Rights Reserved
-- ------------+--------------------------------------------------------
-- Product
--             | SAS Anti-Money Laundering
--             | Anti-Money Laundering Prep View
-- Description
--             | Prep data views containing the data required to execute
--             | scenarios AND risk factors.
-- ------------+--------------------------------------------------------
-- Implementation Notes
--             |find last_dorm_date change to rundate-last_dorm_date
--             | if last_dorm_date is null then dorm_date=0
--             |Select date_key between rundate - 90 AND rundate
------------------------------------------------------------------------
(
account_number
,last_dorm_date
,currency_amount
,date_key
,transaction_key
)
AS
locking row for access 
SELECT
 c.account_number
 ,a1.last_dorm_date
 ,d.currency_amount
 ,d.date_key
 ,d.transaction_key
FROM
 AMLCORE.fsc_account_dim c
 ,AMLCORE.fsc_cash_flow_fact d
 ,(SELECT a.account_number
		,x.last_dorm_date
	FROM AMLCORE.fsc_account_dim a
	,(SELECT account_number
		,CAST(max(change_end_date) AS DATE FORMAT 'YYYY-MM-DD')
		AS last_dorm_date
		FROM AMLCORE.fsc_account_dim
		WHERE  dormant_ind='Y'
		AND segment_id = 'BANK1KCTR'
		AND change_current_ind='N'
		GROUP BY  account_number
	) x
	WHERE a.dormant_ind = 'N'
	AND a.segment_id = 'BANK1KCTR'
	AND a.change_current_ind='Y'
	AND a.account_number = x.account_number
UNION
	SELECT b.account_number
	,NULL AS last_dorm_date
	FROM AMLCORE.fsc_cash_flow_fact a
	,AMLCORE.fsc_account_dim b
	WHERE dormant_ind = 'Y'
	AND a.segment_id = b.segment_id
	AND a.segment_id = 'BANK1KCTR'
	AND change_current_ind = 'Y'
)AS a1
WHERE
 c.account_key = d.account_key
 AND c.segment_id = d.segment_id
 AND c.segment_id = 'BANK1KCTR'
 AND c.account_number = a1.account_number;

REPLACE VIEW BANK1KCTR.PartyProfileView
-- ------------+--------------------------------------------------------
-- Copyright (c) 2006 by SAS Institute Inc., Cary, NC 27513 USA
-- All Rights Reserved
-- ------------+--------------------------------------------------------
-- Product
--             | SAS Anti-Money Laundering
--             | Anti-Money Laundering Prep View
-- Description
--             | Prep data views containing the data required to execute
--             | scenarios AND risk factors.
-- ------------+--------------------------------------------------------
(party_number
,aggregate_Assets_Amount
,Total_Wire_Credits_Amount
,Total_Wire_Debits_Amount
,month_key) 
AS
locking row for access 
SELECT
 party_number
,aggregate_Assets_Amount
,Total_Wire_Credits_Amount
,Total_Wire_Debits_Amount
,month_key
FROM 
	AMLCORE.fsc_party_profile_fact
WHERE segment_id = 'BANK1KCTR';

REPLACE VIEW BANK1KCTR.PartyTaxIdView
-- ------------+--------------------------------------------------------
-- Copyright (c) 2006 by SAS Institute Inc., Cary, NC 27513 USA
-- All Rights Reserved
-- ------------+--------------------------------------------------------
-- Product
--             | SAS Anti-Money Laundering
--             | Anti-Money Laundering Prep View
-- Description
--             | Prep data views containing the data required to execute
--             | scenarios AND risk factors.
-- ------------+--------------------------------------------------------
(STREET_STATE_CODE
,PARTY_TAX_ID
,PARTY_NUMBER
)
AS
locking row for access 
SELECT
	Fsc_party_dim.street_state_code
	,Fsc_party_dim.party_tax_id
	,Fsc_party_dim.party_number
FROM
	AMLCORE.Fsc_party_dim Fsc_party_dim
	WHERE party_tax_id IS NOT NULL
	AND segment_id = 'BANK1KCTR';

REPLACE VIEW BANK1KCTR.PartyTransactionView
-- ------------+--------------------------------------------------------
-- Copyright (c) 2006 by SAS Institute Inc., Cary, NC 27513 USA
-- All Rights Reserved
-- ------------+--------------------------------------------------------
-- Product
--             | SAS Anti-Money Laundering
--             | Anti-Money Laundering Prep View
-- Description
--             | Prep data views containing the data required to execute
--             | scenarios AND risk factors.
-- ------------+--------------------------------------------------------
(account_number
	,account_type_desc
	,annual_income_amount
	,country_code_3
	,currency_amount
	,currency_based_account_ind
	,currency_code
	,customer_since_date
	,date_key
	,last_cash_trans_rpt_date
	,last_susp_actv_rpt_date
	,mechanism_desc
	,party_number
	,politically_exposed_person_ind
	,primary_medium_desc
	,secondary_medium_desc
	,status_desc
	,transaction_cdi_code
	,transaction_key

) 
AS
locking row for access 
SELECT
	A.account_number
	,A.account_type_desc
	,B.annual_income_amount
	,E.country_code_3
	,I.currency_amount
	,A.currency_based_account_ind
	,F.currency_code
	,B.customer_since_date
	,I.date_key
	,B.last_cash_trans_rpt_date
	,B.last_susp_actv_rpt_date
	,C.mechanism_desc
	,B.party_number
	,B.politically_exposed_person_ind
	,C.primary_medium_desc
	,C.secondary_medium_desc
	,G.status_desc
	,C.transaction_cdi_code
	,I.transaction_key
FROM
	AMLCORE.fsc_account_dim A,
	AMLCORE.fsc_party_dim B,
	AMLCORE.fsc_transaction_type_dim C,
	AMLCORE.fsc_branch_dim D,
	AMLCORE.fsc_country_dim E,
	AMLCORE.fsc_currency_dim F,
	AMLCORE.fsc_transaction_status_dim G,
	AMLCORE.fsc_party_account_bridge H,
	AMLCORE.fsc_cash_flow_fact I
WHERE
	I.account_key = A.account_key
	AND I.segment_id = A.segment_id
	AND A.account_key = H.account_key
	AND A.segment_id = H.segment_id
	AND B.party_key = H.party_key
	AND B.segment_id = H.segment_id
	AND I.transaction_type_key = C.transaction_type_key
	AND I.transaction_status_key = G.transaction_status_key
	AND I.country_key = E.country_key
	AND I.branch_key = D.branch_key
	AND I.segment_id = D.segment_id
	AND I.transaction_currency_key = F.currency_key
	AND H.role_desc = 'PRIMARY OWNER'
	AND H.change_current_ind = 'Y'
	AND A.segment_id = 'BANK1KCTR'
UNION ALL
SELECT
	A.account_number
	,A.account_type_desc
	,B.annual_income_amount
	,E.country_code_3
	,0 AS currency_amount
	,A.currency_based_account_ind
	,'' AS currency_code
	,B.customer_since_date
	,I.date_key
	,B.last_cash_trans_rpt_date
	,B.last_susp_actv_rpt_date
	,C.mechanism_desc
	,B.party_number
	,B.politically_exposed_person_ind
	,C.primary_medium_desc
	,C.secondary_medium_desc
	,G.status_desc
	,C.transaction_cdi_code
	,I.transaction_key
FROM
	AMLCORE.fsc_account_dim A,
	AMLCORE.fsc_party_dim B,
	AMLCORE.fsc_transaction_type_dim C,
	AMLCORE.fsc_branch_dim D,
	AMLCORE.fsc_country_dim E,
	AMLCORE.fsc_transaction_status_dim G,
	AMLCORE.fsc_party_account_bridge H,
	AMLCORE.fsc_account_event_fact I
WHERE
	I.account_key = A.account_key
	AND I.segment_id = A.segment_id
	AND A.account_key = H.account_key
	AND A.segment_id = H.segment_id
	AND B.party_key = H.party_key
	AND B.segment_id = H.segment_id
	AND I.transaction_type_key = C.transaction_type_key
	AND I.transaction_status_key = G.transaction_status_key
	AND I.country_key = E.country_key
	AND I.branch_key = D.branch_key
	AND I.segment_id = D.segment_id
	AND H.role_desc = 'PRIMARY OWNER'
	AND H.change_current_ind = 'Y'
	AND A.segment_id = 'BANK1KCTR';
	



REPLACE VIEW BANK2KCTR.AccountProfileView
-- ------------+--------------------------------------------------------
-- Copyright (c) 2006 by SAS Institute Inc., Cary, NC 27513 USA
-- All Rights Reserved
-- ------------+--------------------------------------------------------
-- Product
--             | SAS Anti-Money Laundering
--             | Anti-Money Laundering Prep View
-- Description
--             | Prep data views containing the data required to execute
--             | scenarios AND risk factors.
-- ------------+--------------------------------------------------------
(account_Number
,account_type_desc
,avg_Account_Value_Amount
,cust_Initiated_Trans_Count
,max_Account_Value_Amount
,min_Account_Value_Amount
,month_key
,total_Credits_Amount
,total_Debits_Amount
,total_Wire_Credits_Amount
,total_Wire_Debits_Amount
,wires_Count)
AS
locking row for access 
SELECT
a.account_number
,b.account_type_desc
,a.avg_Account_Value_Amount
,a.cust_Initiated_Trans_Count
,a.max_Account_Value_Amount
,a.min_Account_Value_Amount
,a. month_key
,a.total_Credits_Amount
,a.total_Debits_Amount
,a.total_Wire_Credits_Amount
,a.total_Wire_Debits_Amount
,a.wires_Count
FROM AMLCORE.fsc_account_profile_fact a
	,AMLCORE.fsc_account_dim b
WHERE a.account_number=b.account_number
		AND a.segment_id = b.segment_id
		AND a.segment_id = 'BANK2KCTR'
		AND b.change_current_ind='Y';

REPLACE VIEW BANK2KCTR.AccountTransactionView
-- ------------+--------------------------------------------------------
-- Copyright (c) 2006 by SAS Institute Inc., Cary, NC 27513 USA
-- All Rights Reserved
-- ------------+--------------------------------------------------------
-- Product
--             | SAS Anti-Money Laundering
--             | Anti-Money Laundering Prep View
-- Description
--             | Prep data views containing the data required to execute
--             | scenarios AND risk factors.
-- ------------+--------------------------------------------------------
(
account_number
,account_tax_state_code
,account_type_desc
,annual_income_amount
,branch_number
,branch_type_desc
,currency_amount
,currency_based_account_ind
,currency_code
,customer_since_date
,date_key
,expected_credit_ceiling_amount
,expected_debit_ceiling_amount
,expected_incoming_amount
,expected_incoming_count
,expected_outgoing_amount
,expected_outgoing_count
,increased_behavior_credit_amt
,increased_behavior_credit_cnt
,increased_behavior_debit_amt
,increased_behavior_debit_cnt
,last_cash_trans_rpt_date
,last_susp_actv_rpt_date
,mechanism_desc
,politically_exposed_person_ind
,primary_medium_desc
,secondary_medium_desc
,status_desc
,status_reason_desc
,street_state_code
,transaction_cdi_code
,transaction_key

) 
AS
locking row for access 
SELECT
aa.account_number
,aa.account_tax_state_code
,aa.account_type_desc
,aa.annual_income_amount
,aa.branch_number
,aa.branch_type_desc
,aa.currency_amount
,aa.currency_based_account_ind
,aa.currency_code
,aa.customer_since_date
,aa.date_key
,x.expected_credit_ceiling_amount
,x.expected_debit_ceiling_amount
,x.expected_incoming_amount
,x.expected_incoming_count
,x.expected_outgoing_amount
,x.expected_outgoing_count
,x.increased_behavior_credit_amt
,x.increased_behavior_credit_cnt
,x.increased_behavior_debit_amt
,x.increased_behavior_debit_cnt
,aa.last_cash_trans_rpt_date
,aa.last_susp_actv_rpt_date
,aa.mechanism_desc
,aa.politically_exposed_person_ind
,aa.primary_medium_desc
,aa.secondary_medium_desc
,aa.status_desc
,aa.status_reason_desc
,aa.street_state_code
,aa.transaction_cdi_code
,aa.transaction_key

FROM
(SELECT
 A.account_number
, A.segment_id
, A.account_tax_state_code
, A.account_type_desc
, B.annual_income_amount
, D.branch_number
, D.branch_type_desc
, I.currency_amount
, A.currency_based_account_ind
, F.currency_code
, B.customer_since_date
, I.date_key
, b.last_cash_trans_rpt_date
, b.last_susp_actv_rpt_date
, c.mechanism_desc
, b.politically_exposed_person_ind
, c.primary_medium_desc
, c.secondary_medium_desc
, g.status_desc
, g.status_reason_desc
, d.street_state_code
, c.transaction_cdi_code
, i.transaction_key
FROM
 AMLCORE.fsc_account_dim A
,AMLCORE.fsc_party_dim B
,AMLCORE.fsc_transaction_type_dim C
,AMLCORE.fsc_branch_dim D
,AMLCORE.fsc_country_dim E
,AMLCORE.fsc_currency_dim F
,AMLCORE.fsc_transaction_status_dim G
,AMLCORE.fsc_party_account_bridge H
,AMLCORE.fsc_cash_flow_fact I
WHERE
 I.account_key = A.account_key
 AND I.segment_id = A.segment_id
 AND A.account_key = H.account_key
 AND A.segment_id = H.segment_id
 AND B.party_key = H.party_key
 AND B.segment_id = H.segment_id
 AND I.transaction_type_key = C.transaction_type_key
 AND I.transaction_status_key = G.transaction_status_key
 AND I.country_key = E.country_key
 AND I.branch_key = D.branch_key
 AND I.segment_id = D.segment_id
 AND I.transaction_currency_key = F.currency_key
 AND H.role_desc = 'PRIMARY OWNER'
 AND H.change_current_ind = 'Y'
 AND A.segment_id = 'BANK2KCTR'
UNION ALL
SELECT
 A.account_number
 ,A.segment_id
 ,A.account_tax_state_code
 ,A.account_type_desc
 ,B.annual_income_amount
 ,D.branch_number
 ,D.branch_type_desc
 ,0 as currency_amount
 ,A.currency_based_account_ind
 ,'' as currency_code
 ,B.customer_since_date
 ,I.date_key
 ,B.last_cash_trans_rpt_date
 ,B.last_susp_actv_rpt_date
 ,C.mechanism_desc
 ,B.politically_exposed_person_ind
 ,C.primary_medium_desc
 ,C.secondary_medium_desc
 ,D.street_state_code
 ,G.status_desc
 ,G.status_reason_desc
 ,C.transaction_cdi_code
 ,I.transaction_key
FROM
AMLCORE.fsc_account_dim A
,AMLCORE.fsc_party_dim B
,AMLCORE.fsc_transaction_type_dim C
,AMLCORE.fsc_branch_dim D
,AMLCORE.fsc_country_dim E
,AMLCORE.fsc_transaction_status_dim G
,AMLCORE.fsc_party_account_bridge H
,AMLCORE.fsc_account_event_fact I
WHERE
 I.account_key = A.account_key
 AND I.segment_id = A.segment_id
 AND A.account_key = H.account_key
 AND A.segment_id = H.segment_id
 AND B.party_key = H.party_key
 AND B.segment_id = H.segment_id
 AND I.transaction_type_key = C.transaction_type_key
 AND I.transaction_status_key = G.transaction_status_key
 AND I.country_key = E.country_key
 AND I.branch_key = D.branch_key
 AND I.segment_id = D.segment_id
 AND H.role_desc = 'PRIMARY OWNER'
 AND H.change_current_ind = 'Y'
 AND A.segment_id = 'BANK2KCTR'
)aa
LEFT JOIN
AMLCORE.fsc_account_analysis_dim x
ON
aa.account_number=x.account_number
AND aa.segment_id = x.segment_id
and x.segment_id = 'BANK2KCTR';

REPLACE VIEW BANK2KCTR.DormantAccountTransactionView
-- ------------+--------------------------------------------------------
-- Copyright (c) 2006 by SAS Institute Inc., Cary, NC 27513 USA
-- All Rights Reserved
-- ------------+--------------------------------------------------------
-- Product
--             | SAS Anti-Money Laundering
--             | Anti-Money Laundering Prep View
-- Description
--             | Prep data views containing the data required to execute
--             | scenarios AND risk factors.
-- ------------+--------------------------------------------------------
-- Implementation Notes
--             |find last_dorm_date change to rundate-last_dorm_date
--             | if last_dorm_date is null then dorm_date=0
--             |Select date_key between rundate - 90 AND rundate
------------------------------------------------------------------------
(
account_number
,last_dorm_date
,currency_amount
,date_key
,transaction_key
)
AS
locking row for access 
SELECT
 c.account_number
 ,a1.last_dorm_date
 ,d.currency_amount
 ,d.date_key
 ,d.transaction_key
FROM
 AMLCORE.fsc_account_dim c
 ,AMLCORE.fsc_cash_flow_fact d
 ,(SELECT a.account_number
		,x.last_dorm_date
	FROM AMLCORE.fsc_account_dim a
	,(SELECT account_number
		,CAST(max(change_end_date) AS DATE FORMAT 'YYYY-MM-DD')
		AS last_dorm_date
		FROM AMLCORE.fsc_account_dim
		WHERE  dormant_ind='Y'
		AND segment_id = 'BANK2KCTR'
		AND change_current_ind='N'
		GROUP BY  account_number
	) x
	WHERE a.dormant_ind = 'N'
	AND a.segment_id = 'BANK2KCTR'
	AND a.change_current_ind='Y'
	AND a.account_number = x.account_number
UNION
	SELECT b.account_number
	,NULL AS last_dorm_date
	FROM AMLCORE.fsc_cash_flow_fact a
	,AMLCORE.fsc_account_dim b
	WHERE dormant_ind = 'Y'
	AND a.segment_id = b.segment_id
	AND a.segment_id = 'BANK2KCTR'
	AND change_current_ind = 'Y'
)AS a1
WHERE
 c.account_key = d.account_key
 AND c.segment_id = d.segment_id
 AND c.segment_id = 'BANK2KCTR'
 AND c.account_number = a1.account_number;

REPLACE VIEW BANK2KCTR.PartyProfileView
-- ------------+--------------------------------------------------------
-- Copyright (c) 2006 by SAS Institute Inc., Cary, NC 27513 USA
-- All Rights Reserved
-- ------------+--------------------------------------------------------
-- Product
--             | SAS Anti-Money Laundering
--             | Anti-Money Laundering Prep View
-- Description
--             | Prep data views containing the data required to execute
--             | scenarios AND risk factors.
-- ------------+--------------------------------------------------------
(party_number
,aggregate_Assets_Amount
,Total_Wire_Credits_Amount
,Total_Wire_Debits_Amount
,month_key)
AS
locking row for access 
SELECT
 party_number
,aggregate_Assets_Amount
,Total_Wire_Credits_Amount
,Total_Wire_Debits_Amount
,month_key
FROM 
	AMLCORE.fsc_party_profile_fact
WHERE segment_id = 'BANK2KCTR';

REPLACE VIEW BANK2KCTR.PartyTaxIdView
-- ------------+--------------------------------------------------------
-- Copyright (c) 2006 by SAS Institute Inc., Cary, NC 27513 USA
-- All Rights Reserved
-- ------------+--------------------------------------------------------
-- Product
--             | SAS Anti-Money Laundering
--             | Anti-Money Laundering Prep View
-- Description
--             | Prep data views containing the data required to execute
--             | scenarios AND risk factors.
-- ------------+--------------------------------------------------------
(STREET_STATE_CODE
,PARTY_TAX_ID
,PARTY_NUMBER
)
AS
locking row for access 
SELECT
	Fsc_party_dim.street_state_code
	,Fsc_party_dim.party_tax_id
	,Fsc_party_dim.party_number
FROM
	AMLCORE.Fsc_party_dim Fsc_party_dim
	WHERE party_tax_id IS NOT NULL
	AND segment_id = 'BANK2KCTR';

REPLACE VIEW BANK2KCTR.PartyTransactionView
-- ------------+--------------------------------------------------------
-- Copyright (c) 2006 by SAS Institute Inc., Cary, NC 27513 USA
-- All Rights Reserved
-- ------------+--------------------------------------------------------
-- Product
--             | SAS Anti-Money Laundering
--             | Anti-Money Laundering Prep View
-- Description
--             | Prep data views containing the data required to execute
--             | scenarios AND risk factors.
-- ------------+--------------------------------------------------------
(account_number
	,account_type_desc
	,annual_income_amount
	,country_code_3
	,currency_amount
	,currency_based_account_ind
	,currency_code
	,customer_since_date
	,date_key
	,last_cash_trans_rpt_date
	,last_susp_actv_rpt_date
	,mechanism_desc
	,party_number
	,politically_exposed_person_ind
	,primary_medium_desc
	,secondary_medium_desc
	,status_desc
	,transaction_cdi_code
	,transaction_key

) 
AS
locking row for access 
SELECT
	A.account_number
	,A.account_type_desc
	,B.annual_income_amount
	,E.country_code_3
	,I.currency_amount
	,A.currency_based_account_ind
	,F.currency_code
	,B.customer_since_date
	,I.date_key
	,B.last_cash_trans_rpt_date
	,B.last_susp_actv_rpt_date
	,C.mechanism_desc
	,B.party_number
	,B.politically_exposed_person_ind
	,C.primary_medium_desc
	,C.secondary_medium_desc
	,G.status_desc
	,C.transaction_cdi_code
	,I.transaction_key
FROM
	AMLCORE.fsc_account_dim A,
	AMLCORE.fsc_party_dim B,
	AMLCORE.fsc_transaction_type_dim C,
	AMLCORE.fsc_branch_dim D,
	AMLCORE.fsc_country_dim E,
	AMLCORE.fsc_currency_dim F,
	AMLCORE.fsc_transaction_status_dim G,
	AMLCORE.fsc_party_account_bridge H,
	AMLCORE.fsc_cash_flow_fact I
WHERE
	I.account_key = A.account_key
	AND I.segment_id = A.segment_id
	AND A.account_key = H.account_key
	AND A.segment_id = H.segment_id
	AND B.party_key = H.party_key
	AND B.segment_id = H.segment_id
	AND I.transaction_type_key = C.transaction_type_key
	AND I.transaction_status_key = G.transaction_status_key
	AND I.country_key = E.country_key
	AND I.branch_key = D.branch_key
	AND I.segment_id = D.segment_id
	AND I.transaction_currency_key = F.currency_key
	AND H.role_desc = 'PRIMARY OWNER'
	AND H.change_current_ind = 'Y'
	AND A.segment_id = 'BANK2KCTR'
UNION ALL
SELECT
	A.account_number
	,A.account_type_desc
	,B.annual_income_amount
	,E.country_code_3
	,0 AS currency_amount
	,A.currency_based_account_ind
	,'' AS currency_code
	,B.customer_since_date
	,I.date_key
	,B.last_cash_trans_rpt_date
	,B.last_susp_actv_rpt_date
	,C.mechanism_desc
	,B.party_number
	,B.politically_exposed_person_ind
	,C.primary_medium_desc
	,C.secondary_medium_desc
	,G.status_desc
	,C.transaction_cdi_code
	,I.transaction_key
FROM
	AMLCORE.fsc_account_dim A,
	AMLCORE.fsc_party_dim B,
	AMLCORE.fsc_transaction_type_dim C,
	AMLCORE.fsc_branch_dim D,
	AMLCORE.fsc_country_dim E,
	AMLCORE.fsc_transaction_status_dim G,
	AMLCORE.fsc_party_account_bridge H,
	AMLCORE.fsc_account_event_fact I
WHERE
	I.account_key = A.account_key
	AND I.segment_id = A.segment_id
	AND A.account_key = H.account_key
	AND A.segment_id = H.segment_id
	AND B.party_key = H.party_key
	AND B.segment_id = H.segment_id
	AND I.transaction_type_key = C.transaction_type_key
	AND I.transaction_status_key = G.transaction_status_key
	AND I.country_key = E.country_key
	AND I.branch_key = D.branch_key
	AND I.segment_id = D.segment_id
	AND H.role_desc = 'PRIMARY OWNER'
	AND H.change_current_ind = 'Y'
	AND A.segment_id = 'BANK2KCTR'
;